(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    198474,       4877]
NotebookOptionsPosition[    188203,       4549]
NotebookOutlinePosition[    190661,       4629]
CellTagsIndexPosition[    190340,       4616]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Introduzione alle derivate", "Title"],

Cell[CellGroupData[{

Cell["Introduzione", "Subsubsection"],

Cell[TextData[{
 "Questo notebook di ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " presenta una lezione introduttiva sul significato di derivata di una \
funzione in un suo punto e, in particolare, introduce al suo ",
 StyleBox["significato geometrico",
  FontSlant->"Italic"],
 ". Dapprima si studia il grafico di una funzione ad ingrandimenti sempre \
maggiori nell'intorno di un punto del suo dominio notando come questo, nelle \
situazioni pi\[UGrave] semplici possa essere approssimato da una funzione \
lineare. Si analizza poi il comportamento delle rette secanti e del loro \
coefficiente angolare (o rapporto incrementale) al diminuire dell'incremento, \
suggerendo il significato intuitivo di retta tangente. Fornita la definizione \
formale di derivata si presenta infine il calcolo del limite del rapporto \
incrementale in alcune situazioni particolari."
}], "Text"],

Cell[TextData[{
 ButtonBox["Lorenzo Roi",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["mailto:lroi@mclink.it"], None},
  ButtonNote->"mailto:lroi@mclink.it"],
 "  ",
 StyleBox["(dicembre 2011)",
  FontSlant->"Italic"]
}], "author",
 CellChangeTimes->{{3.5347755688247547`*^9, 3.5347755688247547`*^9}},
 TextAlignment->Right,
 FontFamily->"Helvetica"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Codice", "Subsection"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SetOptions", "[", 
    RowBox[{"Manipulate", ",", 
     RowBox[{"SaveDefinitions", "\[Rule]", "True"}], ",", 
     RowBox[{"ControlPlacement", "\[Rule]", "Top"}]}], "]"}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"zoom", "[", 
     RowBox[{"f_", ",", "x0_"}], "]"}], ":=", 
    RowBox[{"Manipulate", "[", 
     RowBox[{
      RowBox[{"Show", "[", 
       RowBox[{
        RowBox[{"Plot", "[", 
         RowBox[{
          RowBox[{"f", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", 
            RowBox[{"x0", "-", "semiAmpiezza"}], ",", 
            RowBox[{"x0", "+", "semiAmpiezza"}]}], "}"}], ",", 
          RowBox[{"AxesOrigin", "->", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x0", "-", "semiAmpiezza"}], ",", " ", 
             RowBox[{"f", "[", "x0", "]"}]}], "}"}]}], ",", 
          RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}], ",", 
        RowBox[{"Graphics", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"PointSize", "[", "0.025", "]"}], ",", "Blue", ",", 
           RowBox[{"Point", "[", 
            RowBox[{"{", 
             RowBox[{"x0", ",", 
              RowBox[{"f", "[", "x0", "]"}]}], "}"}], "]"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"PlotLabel", "\[Rule]", 
         RowBox[{"Style", "[", 
          RowBox[{
           RowBox[{"\"\<intervallo [\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"PaddedForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"x0", "-", "semiAmpiezza"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"5", ",", "4"}], "}"}]}], "]"}], "]"}], "<>", 
            "\"\<,\>\"", "<>", 
            RowBox[{"ToString", "[", 
             RowBox[{"PaddedForm", "[", 
              RowBox[{
               RowBox[{"N", "[", 
                RowBox[{"x0", "+", "semiAmpiezza"}], "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"5", ",", "4"}], "}"}]}], "]"}], "]"}], "<>", 
            "\"\<]\>\""}], ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
           RowBox[{"FontSize", "\[Rule]", "11"}], ",", 
           RowBox[{"Background", "\[Rule]", 
            RowBox[{"Lighter", "[", "Yellow", "]"}]}]}], "]"}]}]}], "]"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{"semiAmpiezza", ",", "1", ",", "0.001", ",", "0.001"}], 
       "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"rappIncrementale", "[", 
     RowBox[{"f_", ",", "x0_", ",", "h_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"f", "[", 
        RowBox[{"h", "+", "x0"}], "]"}], "-", 
       RowBox[{"f", "[", "x0", "]"}]}], ")"}], "/", "h"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"secante", "[", 
     RowBox[{"f_", ",", "x_", ",", "x0_", ",", "h_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{"rappIncrementale", "[", 
       RowBox[{"f", ",", "x0", ",", "h"}], "]"}], "*", 
      RowBox[{"(", 
       RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
     RowBox[{"f", "[", "x0", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"graficiSecanti", "[", 
     RowBox[{"f_", ",", "x0_", ",", "h_", ",", "estremi_List"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "x", "}"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"h", "\[NotEqual]", "0"}], ",", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"f", "[", "x", "]"}], ",", 
              RowBox[{"secante", "[", 
               RowBox[{"f", ",", "x", ",", "x0", ",", "h"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "Large", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Red", ",", 
               RowBox[{"Point", "[", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"f", "[", "x0", "]"}]}], "}"}], "]"}]}], "}"}], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x0", "+", "h"}], ",", 
                RowBox[{"f", "[", 
                 RowBox[{"x0", "+", "h"}], "]"}]}], "}"}], "]"}]}], "}"}], 
           "]"}], ",", 
          RowBox[{"PlotRange", "->", "estremi"}]}], "]"}], ",", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"f", "[", "x", "]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"f", "'"}], "[", "x0", "]"}], 
                RowBox[{"(", 
                 RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
               RowBox[{"f", "[", "x0", "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "Large", "]"}], ",", "Red", ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{"x0", ",", 
                RowBox[{"f", "[", "x0", "]"}]}], "}"}], "]"}]}], "}"}], "]"}],
           ",", 
          RowBox[{"PlotRange", "->", "estremi"}]}], "]"}]}], "]"}]}], "]"}]}],
    ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"graficiSecantiTriangolo", "[", 
     RowBox[{"f_", ",", "x0_", ",", "h_", ",", "estremi_List"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "x", "}"}], ",", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"h", "\[NotEqual]", "0"}], ",", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"RGBColor", "[", 
              RowBox[{"1", ",", ".9", ",", "0"}], "]"}], ",", 
             RowBox[{"Polygon", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"f", "[", "x0", "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"f", "[", 
                   RowBox[{"x0", "+", "h"}], "]"}]}], "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{
                  RowBox[{"x0", "+", "h"}], ",", 
                  RowBox[{"f", "[", 
                   RowBox[{"x0", "+", "h"}], "]"}]}], "}"}]}], "}"}], 
              StyleBox["]",
               FontWeight->"Plain"]}]}], "}"}], "]"}], ",", 
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"f", "[", "x", "]"}], ",", 
              RowBox[{"secante", "[", 
               RowBox[{"f", ",", "x", ",", "x0", ",", "h"}], "]"}]}], "}"}], 
            ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "Large", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Red", ",", 
               RowBox[{"Point", "[", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"f", "[", "x0", "]"}]}], "}"}], "]"}]}], "}"}], ",", 
             RowBox[{"Point", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x0", "+", "h"}], ",", 
                RowBox[{"f", "[", 
                 RowBox[{"x0", "+", "h"}], "]"}]}], "}"}], "]"}]}], "}"}], 
           "]"}], ",", 
          RowBox[{"PlotRange", "->", "estremi"}], ",", 
          RowBox[{"Axes", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"\"\<coeff. angolare =\>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"PaddedForm", "[", 
                RowBox[{
                 RowBox[{"rappIncrementale", "[", 
                  RowBox[{"f", ",", "x0", ",", "h"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"7", ",", "6"}], "}"}]}], "]"}], "]"}]}], ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
             RowBox[{"FontSize", "\[Rule]", "11"}], ",", 
             RowBox[{"Background", "\[Rule]", 
              RowBox[{"Lighter", "[", "Yellow", "]"}]}]}], "]"}]}]}], "]"}], 
        ",", 
        RowBox[{"Show", "[", 
         RowBox[{
          RowBox[{"Plot", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"f", "[", "x", "]"}], ",", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"f", "'"}], "[", "x0", "]"}], 
                RowBox[{"(", 
                 RowBox[{"x", "-", "x0"}], ")"}]}], "+", 
               RowBox[{"f", "[", "x0", "]"}]}]}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
              RowBox[{"estremi", "[", 
               RowBox[{"[", 
                RowBox[{"1", ",", "2"}], "]"}], "]"}]}], "}"}], ",", 
            RowBox[{"PlotStyle", "\[Rule]", 
             RowBox[{"{", 
              RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], ",", 
          RowBox[{"Graphics", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"PointSize", "[", "Large", "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"Red", ",", 
               RowBox[{"Point", "[", 
                RowBox[{"{", 
                 RowBox[{"x0", ",", 
                  RowBox[{"f", "[", "x0", "]"}]}], "}"}], "]"}]}], "}"}]}], 
            "}"}], "]"}], ",", 
          RowBox[{"PlotRange", "->", "estremi"}], ",", 
          RowBox[{"Axes", "\[Rule]", "True"}], ",", 
          RowBox[{"PlotLabel", "\[Rule]", 
           RowBox[{"Style", "[", 
            RowBox[{
             RowBox[{"\"\<coeff. angolare =\>\"", "<>", 
              RowBox[{"ToString", "[", 
               RowBox[{"PaddedForm", "[", 
                RowBox[{
                 RowBox[{"N", "[", 
                  RowBox[{
                   RowBox[{"f", "'"}], "[", "x0", "]"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"7", ",", "6"}], "}"}]}], "]"}], "]"}]}], ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", 
             RowBox[{"FontSize", "\[Rule]", "11"}], ",", 
             RowBox[{"Background", "\[Rule]", 
              RowBox[{"Lighter", "[", "Yellow", "]"}]}]}], "]"}]}]}], "]"}]}],
        "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"finestra", "[", 
     RowBox[{"f_", ",", "x0_", ",", "h_", ",", "margine_"}], "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"cornice", ",", "minY", ",", "maxY"}], "}"}], ",", 
      RowBox[{
       RowBox[{"cornice", "=", 
        RowBox[{
         RowBox[{"Abs", "[", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x0", "-", "margine"}], "]"}], "-", 
           RowBox[{"f", "[", 
            RowBox[{"x0", "+", "margine"}], "]"}]}], "]"}], "/", "10"}]}], 
       ";", 
       RowBox[{"minY", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x0", "-", "margine"}], "]"}], "\[LessEqual]", 
           RowBox[{"f", "[", 
            RowBox[{"x0", "+", "margine"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x0", "-", "margine"}], "]"}], "-", "cornice"}], ",", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x0", "+", "margine"}], "]"}], "-", "cornice"}]}], 
         "]"}]}], ";", 
       RowBox[{"maxY", "=", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x0", "-", "margine"}], "]"}], "\[LessEqual]", 
           RowBox[{"f", "[", 
            RowBox[{"x0", "+", "margine"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x0", "+", "margine"}], "]"}], "+", "cornice"}], ",", 
          RowBox[{
           RowBox[{"f", "[", 
            RowBox[{"x0", "-", "margine"}], "]"}], "+", "cornice"}]}], 
         "]"}]}], ";", 
       RowBox[{"graficiSecantiTriangolo", "[", 
        RowBox[{"f", ",", "x0", ",", "h", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"x0", "-", "margine"}], ",", 
             RowBox[{"x0", "+", "margine"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"minY", ",", "maxY"}], "}"}]}], "}"}]}], "]"}]}]}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"tavolaCoeffAngolare", "[", 
     RowBox[{"f_", ",", "x0_", ",", "semiAmpiezza_", ",", "nMax_"}], "]"}], ":=", 
    RowBox[{"Sort", "[", 
     RowBox[{
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"N", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{"semiAmpiezza", "/", "#"}], ",", 
                RowBox[{"rappIncrementale", "[", 
                 RowBox[{"f", ",", "x0", ",", 
                  RowBox[{"semiAmpiezza", "/", "#"}]}], "]"}]}], "}"}], "]"}],
              ",", 
             RowBox[{"N", "[", 
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "semiAmpiezza"}], "/", "#"}], ",", 
                RowBox[{"rappIncrementale", "[", 
                 RowBox[{"f", ",", "x0", ",", 
                  RowBox[{
                   RowBox[{"-", "semiAmpiezza"}], "/", "#"}]}], "]"}]}], 
               "}"}], "]"}]}], "}"}], "&"}], ",", 
          RowBox[{"Range", "[", "nMax", "]"}]}], "]"}], ",", "1"}], "]"}], 
      ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#2", "^", "2"}], "<", 
        RowBox[{"#1", "^", "2"}]}], "&"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"tabellaRappIncrementale", "[", 
   RowBox[{"f_", ",", "x0_", ",", "n_"}], "]"}], ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"1", "/", 
         SuperscriptBox["10", "#"]}], "]"}], ",", 
       RowBox[{"rappIncrementale", "[", 
        RowBox[{"f", ",", "x0", ",", 
         RowBox[{"N", "[", 
          RowBox[{"1", "/", 
           SuperscriptBox["10", "#"]}], "]"}]}], "]"}]}], "}"}], "&"}], ",", 
    RowBox[{"Range", "[", "n", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
      "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", 
     "**", "**", "**"}], "*", 
    RowBox[{"**", "**"}]}], "******)"}]}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Grafico di una funzione in intorni di un punto", "Section"],

Cell["Iniziamo definendo una semplice e nota funzione goniometrica", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "x_", "]"}], ":=", 
   RowBox[{"Sin", "[", "x", "]"}]}], ";"}]], "Input"],

Cell[TextData[{
 "e rappresentiamone il grafico nell'intervallo ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{"0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "]"}], TraditionalForm]]],
 " (sistema non isometrico)."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"f", "[", "x", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", 
     RowBox[{"2", "\[Pi]"}]}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "Red"}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwlmXk4lN/7x61ZUmaeISRF+0pKaaH7VEKRUqJFSFpIEhGSSiUk2SvZUpb4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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->
   NCache[{{0, 2 Pi}, {-0.9999998592131705, 0.9999998782112116}}, {{
     0, 6.283185307179586}, {-0.9999998592131705, 0.9999998782112116}}],
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5349176005509524`*^9}]
}, Open  ]],

Cell[TextData[{
 "La nostra intenzione \[EGrave] di studiare tale grafico in intorni del \
punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"[", 
     RowBox[{
      FractionBox["\[Pi]", "3"], ",", 
      RowBox[{"Sin", 
       FractionBox["\[Pi]", "3"]}]}], "]"}], "=", 
    RowBox[{"[", 
     RowBox[{
      FractionBox["\[Pi]", "3"], ",", 
      FractionBox[
       SqrtBox["3"], "2"]}], "]"}]}], TraditionalForm]]],
 ". A tal fine la funzione ",
 StyleBox["zoom[f,x0]", "Input"],
 " permette di ottenere una serie di ingrandimenti attorno al punto ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " del grafico della funzione ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ". Inizialmente l\[CloseCurlyQuote]intervallo nel quale si rappresenta l\
\[CloseCurlyQuote]andamento di ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " \[EGrave] centrato in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " e possiede semiampiezza unitaria: muovendo il cursore verso destra si ",
 StyleBox["diminuisce",
  FontSlant->"Italic"],
 " tale semiampiezza e i nuovi estremi dell\[CloseCurlyQuote]intervallo \
appaiono visualizzati sopra il grafico."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoom", "[", 
  RowBox[{"f", ",", 
   RowBox[{"\[Pi]", "/", "3"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`semiAmpiezza$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`semiAmpiezza$$], 1, 0.001, 0.001}}, Typeset`size$$ = {
    540., {170., 180.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`semiAmpiezza$1272$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`semiAmpiezza$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`semiAmpiezza$$, $CellContext`semiAmpiezza$1272$$, 
         0]}, "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Plot[
         $CellContext`f[$CellContext`x], {$CellContext`x, 
          Rational[1, 3] Pi - $CellContext`semiAmpiezza$$, 
          Rational[1, 3] Pi + $CellContext`semiAmpiezza$$}, 
         AxesOrigin -> {Rational[1, 3] Pi - $CellContext`semiAmpiezza$$, 
           $CellContext`f[Rational[1, 3] Pi]}, PlotStyle -> Red], 
        Graphics[{
          PointSize[0.025], Blue, 
          Point[{Rational[1, 3] Pi, 
            $CellContext`f[Rational[1, 3] Pi]}]}], PlotLabel -> Style[
          StringJoin["intervallo [", 
           ToString[
            PaddedForm[
             N[Rational[1, 3] Pi - $CellContext`semiAmpiezza$$], {5, 4}]], 
           ",", 
           ToString[
            PaddedForm[
             N[Rational[1, 3] Pi + $CellContext`semiAmpiezza$$], {5, 4}]], 
           "]"], FontFamily -> "Helvetica", FontSize -> 11, Background -> 
          Lighter[Yellow]]], 
      "Specifications" :> {{$CellContext`semiAmpiezza$$, 1, 0.001, 0.001}}, 
      "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{612., {238., 247.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`f[
         Pattern[$CellContext`x, 
          Blank[]]] := Sin[$CellContext`x]}; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.5349157964727516`*^9, 3.5349158769531517`*^9}, 
   3.5349176006133523`*^9}]
}, Open  ]],

Cell[TextData[{
 "L'animazione mostra come all'aumentare dell'ingrandimento il tratto di \
sinusoide compreso nell\[CloseCurlyQuote]intervallo tenda ad assumere un \
andamento rettilineo. In una scala molto piccola quindi potremo pensare di \
approssimare tale arco di sinusoide con un segmento e caratterizzare \
quest'ultimo per mezzo del coefficiente angolare della retta che lo comprende \
e che, evidentemente deve passare per ",
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
     FractionBox["\[Pi]", "3"], ",", 
     FractionBox[
      SqrtBox["3"], "2"]}], "]"}], TraditionalForm]]],
 ".\nAl fine di verificare se tali osservazioni possano valere in generale, \
definiamo una seconda funzione e studiamone il comportamento in intorni \
dell'origine: la funzione ",
 Cell[BoxData[
  FormBox["g", TraditionalForm]]],
 " per ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "\[NotEqual]", "0"}], TraditionalForm]]],
 " vale ",
 Cell[BoxData[
  FormBox[
   RowBox[{"Sin", "(", 
    FractionBox["1", "x"], ")"}], TraditionalForm]]],
 " mentre \[EGrave] nulla se ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "=", "0"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g", "[", "x_", "]"}], ":=", 
  RowBox[{
   RowBox[{"Sin", "[", 
    FractionBox["1", "x"], "]"}], "/;", 
   RowBox[{"x", "!=", "0"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "0", "]"}], ":=", "0"}], ";"}]}], "Input",
 CellTags->"funzione_g"],

Cell["Lo zoom attorno all'origine fornisce i grafici seguenti", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoom", "[", 
  RowBox[{"g", ",", "0"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`semiAmpiezza$$ = 1., Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`semiAmpiezza$$], 1, 0.001, 0.001}}, Typeset`size$$ = {
    540., {167., 176.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`semiAmpiezza$1303$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`semiAmpiezza$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`semiAmpiezza$$, $CellContext`semiAmpiezza$1303$$, 
         0]}, "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Plot[
         $CellContext`g[$CellContext`x], {$CellContext`x, 
          0 - $CellContext`semiAmpiezza$$, 0 + $CellContext`semiAmpiezza$$}, 
         AxesOrigin -> {0 - $CellContext`semiAmpiezza$$, 
           $CellContext`g[0]}, PlotStyle -> Red], 
        Graphics[{
          PointSize[0.025], Blue, 
          Point[{0, 
            $CellContext`g[0]}]}], PlotLabel -> Style[
          StringJoin["intervallo [", 
           ToString[
            PaddedForm[
             N[0 - $CellContext`semiAmpiezza$$], {5, 4}]], ",", 
           ToString[
            PaddedForm[
             N[0 + $CellContext`semiAmpiezza$$], {5, 4}]], "]"], FontFamily -> 
          "Helvetica", FontSize -> 11, Background -> Lighter[Yellow]]], 
      "Specifications" :> {{$CellContext`semiAmpiezza$$, 1, 0.001, 0.001}}, 
      "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{612., {235., 244.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`g[0] := 0, $CellContext`g[
         Pattern[$CellContext`x, 
          Blank[]]] := Condition[
         Sin[1/$CellContext`x], $CellContext`x != 0]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.534917600784952*^9}]
}, Open  ]],

Cell[TextData[{
 "che manifestamente mostrano un comportamento del tutto diverso dal \
precedente (in ordinata la funzione continua ad oscillare tra 1 e ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]]],
 " e all'aumentare dell'ingrandimento emergono nuove oscillazioni, sempre pi\
\[UGrave] fitte). Studiando la stessa funzione attorno al punto di ascissa ",
 Cell[BoxData[
  FormBox["0.5", TraditionalForm]]],
 " invece"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoom", "[", 
  RowBox[{"g", ",", "0.5"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`semiAmpiezza$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`semiAmpiezza$$], 1, 0.001, 0.001}}, Typeset`size$$ = {
    540., {167., 176.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`semiAmpiezza$1330$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`semiAmpiezza$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`semiAmpiezza$$, $CellContext`semiAmpiezza$1330$$, 
         0]}, "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Plot[
         $CellContext`g[$CellContext`x], {$CellContext`x, 
          0.5 - $CellContext`semiAmpiezza$$, 
          0.5 + $CellContext`semiAmpiezza$$}, 
         AxesOrigin -> {0.5 - $CellContext`semiAmpiezza$$, 
           $CellContext`g[0.5]}, PlotStyle -> Red], 
        Graphics[{
          PointSize[0.025], Blue, 
          Point[{0.5, 
            $CellContext`g[0.5]}]}], PlotLabel -> Style[
          StringJoin["intervallo [", 
           ToString[
            PaddedForm[
             N[0.5 - $CellContext`semiAmpiezza$$], {5, 4}]], ",", 
           ToString[
            PaddedForm[
             N[0.5 + $CellContext`semiAmpiezza$$], {5, 4}]], "]"], FontFamily -> 
          "Helvetica", FontSize -> 11, Background -> Lighter[Yellow]]], 
      "Specifications" :> {{$CellContext`semiAmpiezza$$, 1, 0.001, 0.001}}, 
      "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{612., {235., 244.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`g[0] := 0, $CellContext`g[
         Pattern[$CellContext`x, 
          Blank[]]] := Condition[
         Sin[1/$CellContext`x], $CellContext`x != 0]}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.534917600925352*^9}]
}, Open  ]],

Cell["\<\
ritroviamo ancora l'andamento notato per la sinusoide. \[CapitalEGrave] \
evidente quindi che per una stessa funzione vi sono punti dove il \
comportamento del grafico, a scale sempre pi\[UGrave] piccole, risulta \
sostanzialmente differente. In particolare vi sono intorni di punti dove \
all'aumentare dell'ingrandimento il grafico della funzione tende ad assumere \
un andamento lineare mentre in altri appare sicuramente pi\[UGrave] complicato.
Nel primo caso potremo pensare di \
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
descrivere geometricamente l\[CloseCurlyQuote]andamento di tali funzioni con \
una retta passante per il punto in questione e che apparir\[AGrave] naturale \
identificare con la retta tangente, mentre\
\>", "Item"],

Cell["\<\
dal punto di vista algebrico tale comportamento potr\[AGrave] essere \
riassunto per mezzo del coefficiente angolare di tale retta.\
\>", "Item"]
}, Open  ]],

Cell["\<\
Nella sezione successiva cercheremo quindi di caratterizzare maggiormente le \
propriet\[AGrave] di quei punti dove l'andamento del grafico appare \
sostanzialmente semplice e assimilabile ad un segmento.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definizione di rapporto incrementale e suo studio", "Section"],

Cell["\<\
Se il grafico di una funzione tende a divenire in intorni di un punto quello \
di un segmento potremo descrivere il suo andamento per mezzo di una retta \
passante per il punto in questione. \
\>", "Text"],

Cell[TextData[{
 "Siccome per ogni relazione lineare (per esempio, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "=", 
    RowBox[{
     RowBox[{"m", " ", "x"}], "+", "q"}]}], TraditionalForm]]],
 ") tra due variabili ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]]],
 " e ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " sussiste la costanza del rapporto tra le variazioni della variabile \
dipendente ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]]],
 " con le corrispondenti variazioni della variabile indipendente e \
ci\[OGrave], nella geometria analitica, \[EGrave] espresso dalla costanza del \
coefficiente angolare"
}], "Item"],

Cell[BoxData[
 FormBox[
  RowBox[{"m", "=", 
   FractionBox[
    RowBox[{
     SubscriptBox["y", "2"], "-", 
     SubscriptBox["y", "1"]}], 
    RowBox[{
     SubscriptBox["x", "2"], "-", 
     SubscriptBox["x", "1"]}]]}], TraditionalForm]], "DisplayFormula"],

Cell[TextData[{
 "cercheremo di individuare per questa retta il suo parametro pi\[UGrave] \
significativo, cio\[EGrave] il suo coefficiente angolare. Di conseguenza in \
questa sezione studiamo, inizialmente dal punto di vista grafico e, \
successivamente con un\[CloseCurlyQuote]analisi numerica, la variazione del \
coefficiente angolare di una retta passante per il punto di ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["P", "0"], "[", 
    RowBox[{
     SubscriptBox["x", 
      RowBox[{"0", ","}]], 
     RowBox[{"f", "(", 
      SubscriptBox["x", "0"], ")"}]}], "]"}], TraditionalForm]]],
 ", ritenuto fisso, e il punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "0"], "+", "h"}], ",", 
     RowBox[{"f", "(", 
      RowBox[{
       SubscriptBox["x", "0"], "+", "h"}], ")"}]}], "]"}], TraditionalForm]]],
 " che invece verr\[AGrave] considerato variabile con ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 " (quest\[CloseCurlyQuote]ultimo definito successivamente come l\
\[CloseCurlyQuote]",
 StyleBox["incremento della variabile indipendente",
  FontSlant->"Italic"],
 "). Verr\[AGrave] quindi analizzata la convergenza o meno di tale \
coefficiente angolare al diminuire di ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 ". Il coefficiente angolare di tale retta \[EGrave] definito, pi\[UGrave] \
propriamente, come il ",
 StyleBox["rapporto incrementale nel punto ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   StyleBox[
    SubscriptBox["x", "0"],
    FontWeight->"Bold"], TraditionalForm]]],
 " della funzione ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ","
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["\[CapitalDelta]f", "\[CapitalDelta]x"], "=", 
   FractionBox[
    RowBox[{
     RowBox[{"f", " ", 
      RowBox[{"(", 
       RowBox[{"h", "+", 
        SubscriptBox["x", "0"]}], ")"}]}], "-", 
     RowBox[{"f", "(", 
      SubscriptBox["x", "0"], ")"}]}], "h"]}], 
  TraditionalForm]], "DisplayFormula",
 CellTags->"rappIncrementale"],

Cell["in quanto \[EGrave] il rapporto", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "dell\[CloseCurlyQuote]incremento ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     RowBox[{"\[CapitalDelta]", 
      StyleBox["f",
       FontSlant->"Italic"]}]], "=", 
    RowBox[{
     RowBox[{"f", "(", 
      RowBox[{
       SubscriptBox["x", "0"], "+", "h"}], ")"}], "-", 
     RowBox[{"f", "(", 
      SubscriptBox["x", "0"], ")"}]}]}], TraditionalForm]]],
 " della funzione e "
}], "Item"],

Cell[TextData[{
 "dell\[CloseCurlyQuote]incremento ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     RowBox[{"\[CapitalDelta]", 
      StyleBox["x",
       FontSlant->"Italic"]}]], 
    StyleBox["=",
     FontSlant->"Plain"], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["x", "0"], "+", "h"}], ")"}], "-", 
      SubscriptBox["x", "0"]}], "=", "h"}]}], TraditionalForm]]],
 " della variabile indipendente."
}], "Item"]
}, Open  ]],

Cell[TextData[{
 "Tale retta \[EGrave] evidentemente una retta secante il grafico di ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ","
}], "Text"],

Cell[TextData[{
 "La ",
 ButtonBox["figura seguente",
  BaseStyle->"Hyperlink",
  ButtonData:>"figura1"],
 " mostra graficamente le convenzioni sui nomi, la retta secante e il \
triangolo avente per cateti i due incrementi, ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"\[CapitalDelta]", 
     StyleBox["f",
      FontSlant->"Italic"]}]], TraditionalForm]]],
 " e ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{"\[CapitalDelta]", 
     StyleBox["x",
      FontSlant->"Italic"]}]], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"1", ",", ".9", ",", "0"}], "]"}], ",", 
        RowBox[{"Polygon", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.6", ",", 
             RowBox[{"Sin", "[", "0.6", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"Sin", "[", "2", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"Sin", "[", "0.6", "]"}]}], "}"}]}], "}"}], "]"}]}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"RGBColor", "[", 
         RowBox[{"0", ",", "0.7", ",", "1"}], "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"0.6", ",", 
             RowBox[{"Sin", "[", "0.6", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"Sin", "[", "0.6", "]"}]}], "}"}]}], "}"}], "]"}], ",", 
        RowBox[{"Arrow", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"Sin", "[", "0.6", "]"}]}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"2", ",", 
             RowBox[{"Sin", "[", "2", "]"}]}], "}"}]}], "}"}], "]"}]}], 
       "}"}]}], "}"}], "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], ",", 
       RowBox[{"secante", "[", 
        RowBox[{"f", ",", "x", ",", ".6", ",", "1.4"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Red", ",", "Blue"}], "}"}]}]}], "]"}], ",", 
   RowBox[{"Graphics", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"PointSize", "[", "Large", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"Red", ",", 
          RowBox[{"Point", "[", 
           RowBox[{"{", 
            RowBox[{"0.6", ",", 
             RowBox[{"Sin", "[", "0.6", "]"}]}], "}"}], "]"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"Point", "[", 
          RowBox[{"{", 
           RowBox[{"2", ",", 
            RowBox[{"Sin", "[", "2", "]"}]}], "}"}], "]"}], "}"}]}], "}"}], 
      ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Text", "[", 
         RowBox[{
         "\"\<\!\(\*SubscriptBox[\(P\), \(0\)]\)[\!\(\*SubscriptBox[\(x\), \
\(0\)]\), f(\!\(\*SubscriptBox[\(x\), \(0\)]\))]\>\"", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{".6", "-", ".1"}], ",", 
            RowBox[{"f", "[", ".6", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"1", ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{
         "\"\<P[\!\(\*SubscriptBox[\(x\), \(0\)]\)+h, \
f(\!\(\*SubscriptBox[\(x\), \(0\)]\)+h)]\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"2.15", ",", 
            RowBox[{"f", "[", "2.05", "]"}]}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}], ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\[CapitalDelta]f\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"2.12", ",", 
            RowBox[{
             RowBox[{"f", "[", "2", "]"}], "-", "0.2"}]}], "}"}]}], "]"}], 
        ",", 
        RowBox[{"Text", "[", 
         RowBox[{"\"\<\[CapitalDelta]x = h\>\"", ",", 
          RowBox[{"{", 
           RowBox[{"1.4", ",", 
            RowBox[{
             RowBox[{"f", "[", ".6", "]"}], "-", "0.08"}]}], "}"}]}], "]"}]}],
        "}"}]}], "}"}], "]"}], ",", 
   RowBox[{"AspectRatio", "\[Rule]", ".5"}]}], "]"}]], "Input",
 CellTags->"figura1"],

Cell[BoxData[
 GraphicsBox[{{
    {RGBColor[1, 0.9, 0], 
     PolygonBox[
      NCache[{{0.6, 0.5646424733950354}, {2, Sin[2]}, {
        2, 0.5646424733950354}}, {{0.6, 0.5646424733950354}, {
        2, 0.9092974268256817}, {2, 0.5646424733950354}}]]}, 
    {RGBColor[0, 0.7, 1], 
     ArrowBox[{{0.6, 0.5646424733950354}, {2, 0.5646424733950354}}], 
     ArrowBox[NCache[{{2, 0.5646424733950354}, {2, Sin[2]}}, {{
        2, 0.5646424733950354}, {2, 0.9092974268256817}}]]}}, {{}, {}, 
    {RGBColor[1, 0, 0], LineBox[CompressedData["
1:eJwt2Hk0VV/YB3BD5VIqUyU0aJZIioS+l1+lKFOlQYRSkjIVDaJBKkpIkgyV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      "]]}, 
    {RGBColor[0, 0, 1], LineBox[CompressedData["
1:eJwV0H881HcAx/Fzd/h+bZWalEmG6LFcD2lTibw/81CsmqRSy4ZOSsxvq5B5
VJweMXEuD0mpplNr/eD8aE1m09Ux3aNHfuX8/u1wuO8VOmLbH6/H8/+XBT/C
O4jNYrG++a//5fxpIO9ziHIRd718SD1UwFpZ5bQ6ew+0m5JEoyUKaB/ZHW0V
+sMzY0OcvFyBAaPgmXJhBKads11FVQoodiT/fVuYBI+8Q03mcgWa/IVrrwkv
Qbm/T7tJpYD3DyaKXGEBeHUz24Ns25DFfCfJET5ESalV+19FbXCS7jRwjanG
ynrX7mNl7YiM9zwiiZRBJngeu764A2GPgzLYVq9Qa5JQzLnTicbhr+kifiPW
TMxIpZIuXLSbYpV/+wYDkrCyRp9uRNnKLlffbkdQVk2Mc2c3tIGhDzrCu7G4
zV6PF9gD/lMfr8xjvfA9+TqA19WDQHVjdfWFfjSXHCy6FdSL9A0VEWLBIKbI
kvLP+3rBrq7YnBw/DBenrtwtfn1Yum6XvCt3BJLm7ONP+/rgUeD6y6RwDPKa
+HnvgH6smKjfkVQxDmPvHWf9hvqR9+KJDufEJAS7171Rhw7A2eyrhc+OqnE1
l0xfHhqAbbdhf2Isg84UJ/ajsEHcv7MsuCxaA+mz4CbFyCDOdH7fYCt4C0Vh
vCgheghRzlt2XRe9w0p14drC6SFoC9z4o5lT0GbonO+IGcaryLyAU7emYSB3
rUvXDsPR3XK+4+YMqvzKW3efVqJ2u+Mdkv8e+b6uT0UaJW4XX3HsvaeF+H1J
unfcCJZb8UL87s7CR3lgjcXUCF7rUOdMKuewMb6jKChxFGVUjPhV7QdsPpW4
YM8eA2+5YQhfOo8e6R7zJT+NYSJjyuiL5gU8LtOz5XNVsEpNtYsIYRGH6Yl5
6VkVeg+3KVyHWERRqBYXz6ngMdDwvixch/ymadn6yblxnI4OCjZW6RBr0WRO
yvw4PMuv7jQ+ySZ1TarOsJQJjM+FnOFMscnF0oxTEp1J3Gw5WxoewyFupSXK
GExCG7wtIG6WQ0Tc2r0R5yZh9iHLNyqeS8oTZ8w01ZMYdE+ro7i6JML90+5i
rho1NvVYnaZLnN090r90VyOEEnMtaD3SHnEpHylqVNxYs60mS48YKWW3UmRq
yJ2cpd5L9cmqNNNF+/UZzIRc3ReQoU+2BsYfGXRjIPMqOLDImCLjaf/ck6Qy
4Ds6FxWJKBLb4XCYfs7ghOrlu/Ycity4G/vI/AWDyJv+bsuuUOTljxK9TTIG
SfT5njPXKGKz2F7Cr2OQ31pr6i2mSKsL7+NKOYPmuIOZcxUUcblhWRXewmDn
k+i4vW0UoQKXWDYOM9gbzpUJOijiYOd5ekTJ4JBljnFlF0X4s+ly1iiD4xd/
l9j0U6Qy2yBhvYpB8mHW+OwYRcKf6TYK1AyqtD/zxfMUabCeS3HUMpA+MC9u
Y9GExWxt3zPLoJ5fvGDIoQmvKm7jsTkGbXWN+Qn6NBH4THcK5//7kWfa4mVI
ky2pzOYxtgYLnvetBctoErTPPoPN1UCPg9g/jGgiNI/sX6mrgVEof6mNCU1G
KlSZ2/U1MDV/6+9rSpMVybwhX0oDy4aUB5lmNHHzCt0WTWuwLnXFB6k5TSJX
/Zp9wUADe6e7u2YtaHJteFh5/SMN/gXtXGbV
      "]]}}, {
    {PointSize[Large], 
     {RGBColor[1, 0, 0], PointBox[{0.6, 0.5646424733950354}]}, 
     PointBox[NCache[{2, Sin[2]}, {2, 0.9092974268256817}]]}, {
     InsetBox["\<\"\\!\\(\\*SubscriptBox[\\(P\\), \
\\(0\\)]\\)[\\!\\(\\*SubscriptBox[\\(x\\), \\(0\\)]\\), \
f(\\!\\(\\*SubscriptBox[\\(x\\), \\(0\\)]\\))]\"\>", \
{0.5, 0.5646424733950354}, {1, 0}], 
     InsetBox["\<\"P[\\!\\(\\*SubscriptBox[\\(x\\), \\(0\\)]\\)+h, \
f(\\!\\(\\*SubscriptBox[\\(x\\), \\(0\\)]\\)+h)]\"\>", \
{2.15, 0.8873623686333755}, {-1, 0}], 
     InsetBox["\<\"\[CapitalDelta]f\"\>", {2.12, 0.7092974268256818}], 
     InsetBox["\<\"\[CapitalDelta]x = h\"\>", {1.4, 0.48464247339503536`}]}}},
  AspectRatio->0.5]], "Output",
 CellChangeTimes->{3.5349176010657525`*^9},
 CellTags->"figura1"]
}, {2}]],

Cell[TextData[{
 "Vediamo quindi cosa succede tracciando via via le diverse rette secanti il \
grafico della funzione ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " nel punto di ascissa ",
 Cell[BoxData[
  FormBox[
   FractionBox["\[Pi]", "3"], TraditionalForm]]],
 ", quando l'incremento ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 " tende gradualmente a valori sempre pi\[UGrave] piccoli."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"graficiSecanti", "[", 
    RowBox[{"f", ",", 
     RowBox[{"\[Pi]", "/", "3"}], ",", "h", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "3.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", "1.2"}], "}"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"h", ",", "1.7", ",", "\"\<incremento\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "2.4"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`h$$ = 1.7, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`h$$], 1.7, "incremento"}, -1, 2.4}}, 
    Typeset`size$$ = {540., {156., 166.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`h$1365$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`h$$ = 1.7}, 
      "ControllerVariables" :> {
        Hold[$CellContext`h$$, $CellContext`h$1365$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`graficiSecanti[$CellContext`f, Pi/
        3, $CellContext`h$$, {{0, 3.5}, {-0.5, 1.2}}], 
      "Specifications" :> {{{$CellContext`h$$, 1.7, "incremento"}, -1, 2.4}}, 
      "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{612., {224., 233.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`graficiSecanti[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          Blank[]], 
         Pattern[$CellContext`estremi, 
          Blank[List]]] := Module[{$CellContext`x}, 
         If[$CellContext`h != 0, 
          Show[
           Plot[{
             $CellContext`f[$CellContext`x], 
             $CellContext`secante[$CellContext`f, $CellContext`x, \
$CellContext`x0, $CellContext`h]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], {Red, 
              Point[{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}]}, 
             Point[{$CellContext`x0 + $CellContext`h, 
               $CellContext`f[$CellContext`x0 + $CellContext`h]}]}], 
           PlotRange -> $CellContext`estremi], 
          Show[
           Plot[{
             $CellContext`f[$CellContext`x], 
             Derivative[
               1][$CellContext`f][$CellContext`x0] ($CellContext`x - \
$CellContext`x0) + $CellContext`f[$CellContext`x0]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], Red, 
             Point[{$CellContext`x0, 
               $CellContext`f[$CellContext`x0]}]}], 
           PlotRange -> $CellContext`estremi]]], $CellContext`f[
         Pattern[$CellContext`x, 
          Blank[]]] := Sin[$CellContext`x], $CellContext`secante[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := $CellContext`rappIncrementale[$CellContext`f, \
$CellContext`x0, $CellContext`h] ($CellContext`x - $CellContext`x0) + \
$CellContext`f[$CellContext`x0], $CellContext`rappIncrementale[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := ($CellContext`f[$CellContext`h + $CellContext`x0] - \
$CellContext`f[$CellContext`x0])/$CellContext`h, 
       Attributes[Derivative] = {NHoldAll, ReadProtected}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5349176011281524`*^9}]
}, Open  ]],

Cell[TextData[{
 "L'animazione mette in evidenza un fascio di rette proprio di centro ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[Pi]", "3"], ",", 
     FractionBox[
      SqrtBox["3"], "2"]}], ")"}], TraditionalForm]]],
 " tutte secanti il grafico di ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " e che, al diminuire dell'incremento, suggeriscono un avvicinamento alla \
retta tangente. Per quanto visto precedentemente, possiamo intuire come il ",
 ButtonBox["rapporto incrementale",
  BaseStyle->"Hyperlink",
  ButtonData:>"rappIncrementale"],
 " (cio\[EGrave] il loro coefficiente angolare) tenda ad assumere un valore \
prossimo a quello del segmento che caratterizzava il grafico della funzione a \
piccola scala. Per rafforzare tale osservazione mostriamo, ancora a livello \
grafico, il triangolo rettangolo che ha per cateti gli incrementi delle due \
variabili.",
 "\n",
 "La nuova rappresentazione \[EGrave] ora"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"graficiSecantiTriangolo", "[", 
    RowBox[{"f", ",", 
     RowBox[{"\[Pi]", "/", "3"}], ",", "h", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "3.5"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "0.5"}], ",", "1.2"}], "}"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"h", ",", "1.7", ",", "\"\<incremento\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "2.4"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`h$$ = 1.7, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`h$$], 1.7, "incremento"}, -1, 2.4}}, 
    Typeset`size$$ = {540., {130., 140.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`h$1392$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`h$$ = 1.7}, 
      "ControllerVariables" :> {
        Hold[$CellContext`h$$, $CellContext`h$1392$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`graficiSecantiTriangolo[$CellContext`f, Pi/
        3, $CellContext`h$$, {{0, 3.5}, {-0.5, 1.2}}], 
      "Specifications" :> {{{$CellContext`h$$, 1.7, "incremento"}, -1, 2.4}}, 
      "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{612., {198., 207.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`graficiSecantiTriangolo[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          Blank[]], 
         Pattern[$CellContext`estremi, 
          Blank[List]]] := Module[{$CellContext`x}, 
         If[$CellContext`h != 0, 
          Show[
           Graphics[{
             RGBColor[1, 0.9, 0], 
             Polygon[{{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}, {$CellContext`x0, 
                $CellContext`f[$CellContext`x0 + $CellContext`h]}, \
{$CellContext`x0 + $CellContext`h, 
                $CellContext`f[$CellContext`x0 + $CellContext`h]}}]}], 
           Plot[{
             $CellContext`f[$CellContext`x], 
             $CellContext`secante[$CellContext`f, $CellContext`x, \
$CellContext`x0, $CellContext`h]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], {Red, 
              Point[{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}]}, 
             Point[{$CellContext`x0 + $CellContext`h, 
               $CellContext`f[$CellContext`x0 + $CellContext`h]}]}], 
           PlotRange -> $CellContext`estremi, Axes -> True, PlotLabel -> Style[
             StringJoin["coeff. angolare =", 
              ToString[
               PaddedForm[
                $CellContext`rappIncrementale[$CellContext`f, \
$CellContext`x0, $CellContext`h], {7, 6}]]], FontFamily -> "Helvetica", 
             FontSize -> 11, Background -> Lighter[Yellow]]], 
          Show[
           Plot[{
             $CellContext`f[$CellContext`x], 
             Derivative[
               1][$CellContext`f][$CellContext`x0] ($CellContext`x - \
$CellContext`x0) + $CellContext`f[$CellContext`x0]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], {Red, 
              Point[{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}]}}], 
           PlotRange -> $CellContext`estremi, Axes -> True, PlotLabel -> Style[
             StringJoin["coeff. angolare =", 
              ToString[
               PaddedForm[
                N[
                 Derivative[1][$CellContext`f][$CellContext`x0]], {7, 6}]]], 
             FontFamily -> "Helvetica", FontSize -> 11, Background -> 
             Lighter[Yellow]]]]], $CellContext`f[
         Pattern[$CellContext`x, 
          Blank[]]] := Sin[$CellContext`x], $CellContext`secante[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := $CellContext`rappIncrementale[$CellContext`f, \
$CellContext`x0, $CellContext`h] ($CellContext`x - $CellContext`x0) + \
$CellContext`f[$CellContext`x0], $CellContext`rappIncrementale[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := ($CellContext`f[$CellContext`h + $CellContext`x0] - \
$CellContext`f[$CellContext`x0])/$CellContext`h, 
       Attributes[Derivative] = {NHoldAll, ReadProtected}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5349176012685523`*^9}]
}, Open  ]],

Cell["\<\
La tendenza ad assumere un valore costante (e quindi per il triangolo \
assumere forme simili) appare in modo pi\[UGrave] marcato osservando il \
comportamento a piccole scale.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"finestra", "[", 
    RowBox[{"f", ",", 
     RowBox[{"\[Pi]", "/", "3"}], ",", "h", ",", "margineX"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"h", ",", 
       RowBox[{"-", ".235"}], ",", "\"\<incremento h\>\""}], "}"}], ",", 
     RowBox[{"-", ".25"}], ",", ".25", ",", ".0001"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"margineX", ",", "0.65", ",", "\"\<ingrandimento\>\""}], "}"}], 
     ",", "0.0001", ",", "1", ",", ".001"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`h$$ = -0.235, $CellContext`margineX$$ = 
    0.65, Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`h$$], -0.235, "incremento h"}, -0.25, 0.25, 
      0.0001}, {{
       Hold[$CellContext`margineX$$], 0.65, "ingrandimento"}, 0.0001, 1, 
      0.001}}, Typeset`size$$ = {540., {150., 159.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`h$1420$$ = 0, $CellContext`margineX$1421$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`h$$ = -0.235, $CellContext`margineX$$ = 
        0.65}, "ControllerVariables" :> {
        Hold[$CellContext`h$$, $CellContext`h$1420$$, 0], 
        Hold[$CellContext`margineX$$, $CellContext`margineX$1421$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`finestra[$CellContext`f, Pi/
        3, $CellContext`h$$, $CellContext`margineX$$], 
      "Specifications" :> {{{$CellContext`h$$, -0.235, "incremento h"}, -0.25,
          0.25, 0.0001}, {{$CellContext`margineX$$, 0.65, "ingrandimento"}, 
         0.0001, 1, 0.001}}, "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{612., {239., 248.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`finestra[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          Blank[]], 
         Pattern[$CellContext`margine, 
          Blank[]]] := 
       Module[{$CellContext`cornice, $CellContext`minY, $CellContext`maxY}, \
$CellContext`cornice = 
          Abs[$CellContext`f[$CellContext`x0 - $CellContext`margine] - \
$CellContext`f[$CellContext`x0 + $CellContext`margine]]/10; $CellContext`minY = 
          If[$CellContext`f[$CellContext`x0 - $CellContext`margine] <= \
$CellContext`f[$CellContext`x0 + $CellContext`margine], \
$CellContext`f[$CellContext`x0 - $CellContext`margine] - \
$CellContext`cornice, $CellContext`f[$CellContext`x0 + $CellContext`margine] - \
$CellContext`cornice]; $CellContext`maxY = 
          If[$CellContext`f[$CellContext`x0 - $CellContext`margine] <= \
$CellContext`f[$CellContext`x0 + $CellContext`margine], \
$CellContext`f[$CellContext`x0 + $CellContext`margine] + \
$CellContext`cornice, $CellContext`f[$CellContext`x0 - $CellContext`margine] + \
$CellContext`cornice]; $CellContext`graficiSecantiTriangolo[$CellContext`f, \
$CellContext`x0, $CellContext`h, {{$CellContext`x0 - $CellContext`margine, \
$CellContext`x0 + $CellContext`margine}, {$CellContext`minY, \
$CellContext`maxY}}]], $CellContext`f[
         Pattern[$CellContext`x, 
          Blank[]]] := 
       Sin[$CellContext`x], $CellContext`graficiSecantiTriangolo[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          Blank[]], 
         Pattern[$CellContext`estremi, 
          Blank[List]]] := Module[{$CellContext`x}, 
         If[$CellContext`h != 0, 
          Show[
           Graphics[{
             RGBColor[1, 0.9, 0], 
             Polygon[{{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}, {$CellContext`x0, 
                $CellContext`f[$CellContext`x0 + $CellContext`h]}, \
{$CellContext`x0 + $CellContext`h, 
                $CellContext`f[$CellContext`x0 + $CellContext`h]}}]}], 
           Plot[{
             $CellContext`f[$CellContext`x], 
             $CellContext`secante[$CellContext`f, $CellContext`x, \
$CellContext`x0, $CellContext`h]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], {Red, 
              Point[{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}]}, 
             Point[{$CellContext`x0 + $CellContext`h, 
               $CellContext`f[$CellContext`x0 + $CellContext`h]}]}], 
           PlotRange -> $CellContext`estremi, Axes -> True, PlotLabel -> Style[
             StringJoin["coeff. angolare =", 
              ToString[
               PaddedForm[
                $CellContext`rappIncrementale[$CellContext`f, \
$CellContext`x0, $CellContext`h], {7, 6}]]], FontFamily -> "Helvetica", 
             FontSize -> 11, Background -> Lighter[Yellow]]], 
          Show[
           Plot[{
             $CellContext`f[$CellContext`x], 
             Derivative[
               1][$CellContext`f][$CellContext`x0] ($CellContext`x - \
$CellContext`x0) + $CellContext`f[$CellContext`x0]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], {Red, 
              Point[{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}]}}], 
           PlotRange -> $CellContext`estremi, Axes -> True, PlotLabel -> Style[
             StringJoin["coeff. angolare =", 
              ToString[
               PaddedForm[
                N[
                 Derivative[1][$CellContext`f][$CellContext`x0]], {7, 6}]]], 
             FontFamily -> "Helvetica", FontSize -> 11, Background -> 
             Lighter[Yellow]]]]], $CellContext`secante[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := $CellContext`rappIncrementale[$CellContext`f, \
$CellContext`x0, $CellContext`h] ($CellContext`x - $CellContext`x0) + \
$CellContext`f[$CellContext`x0], $CellContext`rappIncrementale[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := ($CellContext`f[$CellContext`h + $CellContext`x0] - \
$CellContext`f[$CellContext`x0])/$CellContext`h, 
       Attributes[Derivative] = {NHoldAll, ReadProtected}}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5349176014245524`*^9}]
}, Open  ]],

Cell["\<\
Mano a mano che il punto variabile (color nero) si avvicina a quello fisso \
(di colore rosso)\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "le rette secanti approssimano sempre meglio l\[CloseCurlyQuote]andamento \
della funzione in intorni del punto ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " confondendosi con il grafico divenuto approssimativamente lineare di ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ". Possiamo ben dire quindi che tali rette si avvicinano a quella retta che, \
passando per ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 ", ",
 StyleBox["approssima nel modo migliore l\[CloseCurlyQuote]andamento di ",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox["f", TraditionalForm]],
  FontSlant->"Italic"],
 StyleBox[" cio\[EGrave] la retta tangente",
  FontSlant->"Italic"],
 ". Contemporaneamente"
}], "Item"],

Cell["\<\
sembra diminuire la variabilit\[AGrave] del loro coefficiente angolare:\
\>", "Item"]
}, Open  ]],

Cell["\<\
 il rapporto incrementale della funzione pare quindi convergere. A scala \
ancora maggiore queste osservazioni appaiono sempre pi\[UGrave] confermate e \
indipendentemente dal segno dell\[CloseCurlyQuote]incremento.\
\>", "Text"],

Cell[TextData[{
 "Per analizzare con maggior precisione la variabilit\[AGrave] del ",
 ButtonBox["rapporto incrementale",
  BaseStyle->"Hyperlink",
  ButtonData:>"rappIncrementale"],
 " conviene passare al suo calcolo numerico esplicito. Nella ",
 ButtonBox["tabella seguente",
  BaseStyle->"Hyperlink",
  ButtonData:>"tabella"],
 " si sono quindi calcolati 100 rapporti incrementali sia in intorni destri \
che sinistri di ",
 Cell[BoxData[
  FormBox[
   FractionBox["\[Pi]", "3"], TraditionalForm]]],
 "a partire da un incremento massimo unitario (in valore assoluto). Il pi\
\[UGrave] piccolo incremento \[EGrave] quindi, in valore assoluto, pari a ",
 Cell[BoxData[
  FormBox["0.01", TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "Nella tabella le coppie (incremento, rapporto incrementale) sono ordinate \
secondo il valore decrescente del valore assoluto dell'incremento ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 " in modo da poter osservare pi\[UGrave] facilmente la convergenza del \
rapporto incrementale al diminuire (del valore assoluto) di ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"Prepend", "[", 
        RowBox[{"#", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<incremento h\>\"", ",", "Bold", ",", 
             RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
           ",", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<rapp. incrementale\>\"", ",", "Bold", ",", 
             RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
            "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Alignment", "\[Rule]", 
        RowBox[{"{", "Right", "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "All"}], ",", 
       RowBox[{"ItemStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"FontSize", "\[Rule]", "8"}], "]"}]}]}], "]"}], "&"}], "/@", 
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"tavolaCoeffAngolare", "[", 
       RowBox[{"f", ",", 
        RowBox[{"\[Pi]", "/", "3"}], ",", "1", ",", "100"}], "]"}], ",", 
      "50"}], "]"}]}], ",", "\"\<   \>\""}], "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {
      "1.`", "0.022625611224628583`"}, {
       RowBox[{"-", "1.`"}], "0.8188453735832677`"}, {
      "0.5`", "0.2673923160659102`"}, {
       RowBox[{"-", "0.5`"}], "0.6914587611424956`"}, {
      "0.3333333333333333`", "0.347785996814305`"}, {
       RowBox[{"-", "0.3333333333333333`"}], "0.6337980935741516`"}, {
      "0.25`", "0.3871173883461694`"}, {
       RowBox[{"-", "0.25`"}], "0.6024984486719225`"}, {
      "0.2`", "0.4103590771184312`"}, {
       RowBox[{"-", "0.2`"}], "0.5829875768568749`"}, {
      "0.16666666666666666`", "0.4256865171950539`"}, {
       RowBox[{"-", "0.16666666666666666`"}], "0.5696902789654359`"}, {
      "0.14285714285714285`", "0.43654722762815357`"}, {
       RowBox[{"-", "0.14285714285714285`"}], "0.560054880917692`"}, {
      "0.125`", "0.4446427864354643`"}, {
       RowBox[{"-", "0.125`"}], "0.5527550806463566`"}, {
      "0.1111111111111111`", "0.4509087839769341`"}, {
       RowBox[{"-", "0.1111111111111111`"}], "0.5470348726126419`"}, {
      "0.1`", "0.45590188541076104`"}, {
       RowBox[{"-", "0.1`"}], "0.54243228105752`"}, {
      "0.09090909090909091`", "0.45997389148791523`"}, {
       RowBox[{"-", "0.09090909090909091`"}], "0.5386492671096583`"}, {
      "0.08333333333333333`", "0.46335798271546924`"}, {
       RowBox[{"-", "0.08333333333333333`"}], "0.5354850116882539`"}, {
      "0.07692307692307693`", "0.46621480099676427`"}, {
       RowBox[{"-", "0.07692307692307693`"}], "0.5327992974414105`"}, {
      "0.07142857142857142`", "0.4686586077262893`"}, {
       RowBox[{"-", "0.07142857142857142`"}], "0.5304912690348094`"}, {
      "0.06666666666666667`", "0.47077288855379373`"}, {
       RowBox[{"-", "0.06666666666666667`"}], "0.5284865352971008`"}, {
      "0.0625`", "0.4726200573897401`"}, {
       RowBox[{"-", "0.0625`"}], "0.5267290280883437`"}, {
      "0.058823529411764705`", "0.47424770767238666`"}, {
       RowBox[{"-", "0.058823529411764705`"}], "0.5251756908259577`"}, {
      "0.05555555555555555`", "0.4756927634998358`"}, {
       RowBox[{"-", "0.05555555555555555`"}], "0.5237929125853731`"}, {
      "0.05263157894736842`", "0.47698430990340734`"}, {
       RowBox[{"-", "0.05263157894736842`"}], "0.5225540735199642`"}, {
      "0.05`", "0.4781455677852886`"}, {
       RowBox[{"-", "0.05`"}], "0.5214378176282763`"}, {
      "0.047619047619047616`", "0.4791953005649501`"}, {
       RowBox[{"-", "0.047619047619047616`"}], "0.520426813332466`"}, {
      "0.045454545454545456`", "0.4801488345456655`"}, {
       RowBox[{"-", "0.045454545454545456`"}], "0.5195068484091212`"}, {
      "0.043478260869565216`", "0.48101881131764535`"}, {
       RowBox[{"-", "0.043478260869565216`"}], "0.5186661585984553`"}, {
      "0.041666666666666664`", "0.4818157508404015`"}, {
       RowBox[{"-", "0.041666666666666664`"}], "0.5178949224240545`"}, {
      "0.04`", "0.4825484785351525`"}, {
       RowBox[{"-", "0.04`"}], "0.5171848761307024`"}}, AutoDelete -> False, 
     GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"],TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {
      "0.038461538461538464`", "0.48322445321560803`"}, {
       RowBox[{"-", "0.038461538461538464`"}], "0.5165290166960994`"}, {
      "0.037037037037037035`", "0.4838500217130757`"}, {
       RowBox[{"-", "0.037037037037037035`"}], "0.5159213702816348`"}, {
      "0.03571428571428571`", "0.4844306186245375`"}, {
       RowBox[{"-", "0.03571428571428571`"}], "0.5153568098987531`"}, {
      "0.034482758620689655`", "0.48497092450193746`"}, {
       RowBox[{"-", "0.034482758620689655`"}], "0.5148309105062562`"}, {
      "0.03333333333333333`", "0.4854749922310242`"}, {
       RowBox[{"-", "0.03333333333333333`"}], "0.5143398328715831`"}, {
      "0.03225806451612903`", "0.48594634881990517`"}, {
       RowBox[{"-", "0.03225806451612903`"}], "0.5138802297489179`"}, {
      "0.03125`", "0.4863880780034897`"}, {
       RowBox[{"-", "0.03125`"}], "0.5134491695269467`"}, {
      "0.030303030303030304`", "0.4868028877531989`"}, {
       RowBox[{"-", "0.030303030303030304`"}], "0.5130440736659463`"}, {
      "0.029411764705882353`", "0.4871931658146049`"}, {
       RowBox[{"-", "0.029411764705882353`"}], "0.5126626651040369`"}, {
      "0.02857142857142857`", "0.4875610256786195`"}, {
       RowBox[{"-", "0.02857142857142857`"}], "0.5123029254527489`"}, {
      "0.027777777777777776`", "0.487908344854898`"}, {
       RowBox[{"-", "0.027777777777777776`"}], "0.5119630592834152`"}, {
      "0.02702702702702703`", "0.48823679691035615`"}, {
       RowBox[{"-", "0.02702702702702703`"}], "0.5116414641710156`"}, {
      "0.02631578947368421`", "0.48854787842628644`"}, {
       RowBox[{"-", "0.02631578947368421`"}], "0.5113367054409168`"}, {
      "0.02564102564102564`", "0.48884293179013505`"}, {
       RowBox[{"-", "0.02564102564102564`"}], "0.5110474947792938`"}, {
      "0.025`", "0.48912316455381966`"}, {
       RowBox[{"-", "0.025`"}], "0.5107726720346717`"}, {
      "0.024390243902439025`", "0.4893896659472955`"}, {
       RowBox[{"-", "0.024390243902439025`"}], "0.5105111896687818`"}, {
      "0.023809523809523808`", "0.4896434210233429`"}, {
       RowBox[{"-", "0.023809523809523808`"}], "0.5102620994173508`"}, {
      "0.023255813953488372`", "0.48988532282072894`"}, {
       RowBox[{"-", "0.023255813953488372`"}], "0.51002454080297`"}, {
      "0.022727272727272728`", "0.49011618286223646`"}, {
       RowBox[{"-", "0.022727272727272728`"}], "0.5097977312068163`"}, {
      "0.022222222222222223`", "0.4903367402475489`"}, {
       RowBox[{"-", "0.022222222222222223`"}], "0.509580957257888`"}, {
      "0.021739130434782608`", "0.4905476695556146`"}, {
       RowBox[{"-", "0.021739130434782608`"}], "0.5093735673401993`"}, {
      "0.02127659574468085`", "0.4907495877344378`"}, {
       RowBox[{"-", "0.02127659574468085`"}], "0.5091749650522254`"}, {
      "0.020833333333333332`", "0.490943060126547`"}, {
       RowBox[{"-", "0.020833333333333332`"}], "0.5089846034803074`"}, {
      "0.02040816326530612`", "0.49112860575396067`"}, {
       RowBox[{"-", "0.02040816326530612`"}], "0.5088019801702681`"}, {
      "0.02`", "0.4913067019667705`"}, {
       RowBox[{"-", "0.02`"}], "0.5086266326998823`"}}, AutoDelete -> False, 
     GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"],TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {
      "0.0196078431372549`", "0.49147778854291924`"}, {
       RowBox[{"-", "0.0196078431372549`"}], "0.5084581347701125`"}, {
      "0.019230769230769232`", "0.4916422713133364`"}, {
       RowBox[{"-", "0.019230769230769232`"}], "0.5082960927455278`"}, {
      "0.018867924528301886`", "0.49180052537529795`"}, {
       RowBox[{"-", "0.018867924528301886`"}], "0.5081401425848185`"}, {
      "0.018518518518518517`", "0.4919528979476053`"}, {
       RowBox[{"-", "0.018518518518518517`"}], "0.5079899471110694`"}, {
      "0.01818181818181818`", "0.49209971091326465`"}, {
       RowBox[{"-", "0.01818181818181818`"}], "0.5078451935786815`"}, {
      "0.017857142857142856`", "0.4922412630888564`"}, {
       RowBox[{"-", "0.017857142857142856`"}], "0.5077055914999908`"}, {
      "0.017543859649122806`", "0.492377832254316`"}, {
       RowBox[{"-", "0.017543859649122806`"}], "0.507570870699884`"}, {
      "0.017241379310344827`", "0.4925096769720747`"}, {
       RowBox[{"-", "0.017241379310344827`"}], "0.5074407795708886`"}, {
      "0.01694915254237288`", "0.49263703822062554`"}, {
       RowBox[{"-", "0.01694915254237288`"}], "0.5073150835050971`"}, {
      "0.016666666666666666`", "0.4927601408643123`"}, {
       RowBox[{"-", "0.016666666666666666`"}], "0.5071935634823932`"}, {
      "0.01639344262295082`", "0.4928791949779976`"}, {
       RowBox[{"-", "0.01639344262295082`"}], "0.507076014797026`"}, {
      "0.016129032258064516`", "0.4929943970433306`"}, {
       RowBox[{"-", "0.016129032258064516`"}], "0.5069622459070311`"}, {
      "0.015873015873015872`", "0.4931059310306376`"}, {
       RowBox[{"-", "0.015873015873015872`"}], "0.5068520773928828`"}, {
      "0.015625`", "0.49321396937912`"}, {
       RowBox[{"-", "0.015625`"}], "0.5067453410134206`"}, {
      "0.015384615384615385`", "0.4933186738863876`"}, {
       RowBox[{"-", "0.015384615384615385`"}], "0.5066418788486948`"}, {
      "0.015151515151515152`", "0.4934201965168439`"}, {
       RowBox[{"-", "0.015151515151515152`"}], "0.5065415425204385`"}, {
      "0.014925373134328358`", "0.493518680137473`"}, {
       RowBox[{"-", "0.014925373134328358`"}], "0.5064441924822027`"}, {
      "0.014705882352941176`", "0.49361425918860613`"}, {
       RowBox[{"-", "0.014705882352941176`"}], "0.5063496973718458`"}, {
      "0.014492753623188406`", "0.4937070602961213`"}, {
       RowBox[{"-", "0.014492753623188406`"}], "0.5062579334202509`"}, {
      "0.014285714285714285`", "0.4937972028310933`"}, {
       RowBox[{"-", "0.014285714285714285`"}], "0.5061687839105367`"}, {
      "0.014084507042253521`", "0.4938847994220168`"}, {
       RowBox[{"-", "0.014084507042253521`"}], "0.5060821386828095`"}, {
      "0.013888888888888888`", "0.4939699564242037`"}, {
       RowBox[{"-", "0.013888888888888888`"}], "0.505997893680119`"}, {
      "0.0136986301369863`", "0.49405277435055384`"}, {
       RowBox[{"-", "0.0136986301369863`"}], "0.5059159505316174`"}, {
      "0.013513513513513514`", "0.49413334826725874`"}, {
       RowBox[{"-", "0.013513513513513514`"}], "0.5058362161693903`"}, {
      "0.013333333333333334`", "0.4942117681578484`"}, {
       RowBox[{"-", "0.013333333333333334`"}], "0.5057586024758975`"}}, 
     AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"],TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {
      "0.013157894736842105`", "0.49428811925834104`"}, {
       RowBox[{"-", "0.013157894736842105`"}], "0.5056830259591294`"}, {
      "0.012987012987012988`", "0.494362482366267`"}, {
       RowBox[{"-", "0.012987012987012988`"}], "0.5056094074530737`"}, {
      "0.01282051282051282`", "0.49443493412587625`"}, {
       RowBox[{"-", "0.01282051282051282`"}], "0.5055376718410922`"}, {
      "0.012658227848101266`", "0.49450554729159346`"}, {
       RowBox[{"-", "0.012658227848101266`"}], "0.5054677478003088`"}, {
      "0.0125`", "0.49457439097170486`"}, {
       RowBox[{"-", "0.0125`"}], "0.5053995675650746`"}, {
      "0.012345679012345678`", "0.4946415308539157`"}, {
       RowBox[{"-", "0.012345679012345678`"}], "0.5053330667079527`"}, {
      "0.012195121951219513`", "0.49470702941442757`"}, {
       RowBox[{"-", "0.012195121951219513`"}], "0.5052681839366577`"}, {
      "0.012048192771084338`", "0.4947709461117844`"}, {
       RowBox[{"-", "0.012048192771084338`"}], "0.5052048609056353`"}, {
      "0.011904761904761904`", "0.4948333375669418`"}, {
       RowBox[{"-", "0.011904761904761904`"}], "0.5051430420411029`"}, {
      "0.011764705882352941`", "0.4948942577304982`"}, {
       RowBox[{"-", "0.011764705882352941`"}], "0.5050826743783876`"}, {
      "0.011627906976744186`", "0.4949537580383161`"}, {
       RowBox[{"-", "0.011627906976744186`"}], "0.5050237074105846`"}, {
      "0.011494252873563218`", "0.49501188755632775`"}, {
       RowBox[{"-", "0.011494252873563218`"}], "0.5049660929476039`"}, {
      "0.011363636363636364`", "0.49506869311549817`"}, {
       RowBox[{"-", "0.011363636363636364`"}], "0.5049097849848971`"}, {
      "0.011235955056179775`", "0.495124219437602`"}, {
       RowBox[{"-", "0.011235955056179775`"}], "0.5048547395808789`"}, {
      "0.011111111111111112`", "0.495178509252695`"}, {
       RowBox[{"-", "0.011111111111111112`"}], "0.5048009147426213`"}, {
      "0.01098901098901099`", "0.4952316034087546`"}, {
       RowBox[{"-", "0.01098901098901099`"}], "0.5047482703190104`"}, {
      "0.010869565217391304`", "0.4952835409741314`"}, {
       RowBox[{"-", "0.010869565217391304`"}], "0.5046967679008585`"}, {
      "0.010752688172043012`", "0.4953343593334698`"}, {
       RowBox[{"-", "0.010752688172043012`"}], "0.5046463707274392`"}, {
      "0.010638297872340425`", "0.4953840942774441`"}, {
       RowBox[{"-", "0.010638297872340425`"}], "0.5045970435990159`"}, {
      "0.010526315789473684`", "0.49543278008675085`"}, {
       RowBox[{"-", "0.010526315789473684`"}], "0.5045487527948767`"}, {
      "0.010416666666666666`", "0.49548044961099436`"}, {
       RowBox[{"-", "0.010416666666666666`"}], "0.5045014659963734`"}, {
      "0.010309278350515464`", "0.49552713434251217`"}, {
       RowBox[{"-", "0.010309278350515464`"}], "0.5044551522149265`"}, {
      "0.01020408163265306`", "0.49557286448582993`"}, {
       RowBox[{"-", "0.01020408163265306`"}], "0.5044097817241877`"}, {
      "0.010101010101010102`", "0.4956176690227653`"}, {
       RowBox[{"-", "0.010101010101010102`"}], "0.5043653259964777`"}, {
      "0.01`", "0.4956615757736871`"}, {
       RowBox[{"-", "0.01`"}], "0.5043217576429782`"}}, AutoDelete -> False, 
     GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"]},
  "Row",
  DisplayFunction->(RowBox[{#, "   ", #2, "   ", #3, "   ", #4}]& ),
  InterpretationFunction->(RowBox[{"Row", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", "\"   \""}], 
     "]"}]& )]], "Output",
 CellChangeTimes->{3.5349176016117525`*^9}]
}, Open  ]],

Cell[TextData[{
 "La rappresentazione grafica di questi coppie di valori mostra chiaramente \
la tendenza per il rapporto incrementale a convergere verso un determinato \
valore (",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"\[Rule]", " ", "0.5"}]}], TraditionalForm]]],
 ") al tendere allo zero dell'incremento."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"tavolaCoeffAngolare", "[", 
    RowBox[{"f", ",", 
     RowBox[{"\[Pi]", "/", "3"}], ",", "1", ",", "100"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<incremento\>\"", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<rapp. incrementale\>\"", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJw11QlYzdkbB/C0qPlnSSLTXtIiFeqfLHnbVMjyDwlRaUz+xFSTkKS41W2/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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     StyleBox[
     "\"incremento\"", FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    FormBox[
     StyleBox[
     "\"rapp. incrementale\"", FontFamily -> "Helvetica", StripOnInput -> 
      False], TraditionalForm]},
  AxesOrigin->{0, 0.445},
  PlotRange->{{-0.11230158730158729`, 0.1130952380952381}, {0.445, 
   0.5488947963495253}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5349176017365522`*^9}]
}, {2}]],

Cell[TextData[{
 "Per mostrare come nel caso della ",
 ButtonBox["funzione g",
  BaseStyle->"Hyperlink",
  ButtonData:>"funzione_g"],
 " e nel punto di ascissa nulla l'andamento del rapporto incrementale sia \
totalmente diverso proponiamo lo stesso calcolo eseguito sopra per la ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " e nel quale l'intervallo iniziale di ampiezza unitaria (sia destra che \
sinistra) \[EGrave] stato gradualmente suddiviso in intervalli sempre pi\
\[UGrave] piccoli fino ad arrivare ad un valore minimo per l'incremento pari \
a ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"tavolaCoeffAngolare", "[", 
    RowBox[{"g", ",", "0", ",", "1", ",", 
     SuperscriptBox["10", "3"]}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<incremento\>\"", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<rapp. incrementale\>\"", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxV3AVUlFv7NnDHArsFEbuwO1HvwQIVlBmG7u7u7haQsAu7EwvrHvWI3a1g
d2Ir1sf/3c/lWt+cWeus31rnIM4Mz7P3va+Lbi6BSve6derUuaRRp87//Vs8
quld00YFqrevSDL//35A03ZffvVV+zfMsPn/HtdJU160RqV9F2ZY/PeXaFvn
yqry0ZpqyQwvXvR/j9OkdtwydufANjDD4uudoK6fNU1fXalhyQwX9Zxe+zxG
J726bDJ0by2XzLD489QUe1Gv9MqGLjDDuieDa5+HKHXP+V/9tjSDGRbfTzn1
7hFUVnGsnfT9lTM8Tcs+7PLUfbSrgfzhh7+9YIbF97uHorSPh3od7QAz3FZ/
Zxv9nWXULuhlzOTb7eSSGRZ/n10Ud2WA35ZD/WGGW/3vsZMO3Nj5amRKD5hh
8ffdQd+7OmrW9W8tvf47GO78v8c2srRKja1jNQRmWLweW+h1cruRHRr1hxnW
277yUMbHTbQ3b3Vpg1MN5ZIZFq/XRmo6zWaR4aRhMMPaGc61zw20u9kWy8rC
oTDD4vVcTztozJL7b06xZIbdujWxPjVpHd0eu3hPbsRwtWSGxeu9lppcvLL4
/sGRMMOxbbcZPoxZQ1823L/rFdUYZli8H6spJv/I2flXh0vvz2qGvQavPJz2
dRVpXzfwj7oyFmZYvF+rKOLJ/j7elp1hhufH6jiXr19JP3ovcL88cbhaMsPi
/VxJY0/2G91uzQSY4bSWkzS7pZXSss/5Ox417QszLN7vUvJwn1Q4fe1Q6fNQ
yrBml7jqoxoraO3eoztKE+Uww+LzsJxiG4w/3P33UJjhTtcMap/LqOFf6wLN
HwPVkhkWn5el9Gfi/epOdwxghi8dONr2x5YlFO3+7O6Ci6NhhsXnaTEt1hi5
rldGb+nztZhhnTUGtc/FNDrsyoQpZyfBDIvP2yJSd04N/nJ+AsxwjfbSgqM/
FtKpzwGjl9XTUUtmWHweF1LYq2zDMTQZZvhzg3gDx0sLKNpnSHH7RwYww+Lz
uoCsr+xftuLNC5LMsJbf0fZ+R+fTH1MtkxG9JsslMyw+z/OJk0uuHjg8BWbY
smVx/6zT88j+vLrCTF8LZlh83ufRSv3kDnpBk6TP/zyGxzYYvP7B0xJKvpl6
8r29Icyw+HkooQ2dbG+eHd8PZrjt/x4lpGfVM89Ay0Aumf/5fz8vxfToxPmp
f9ZNhxk+GtX/p66ymD5eTZ338ucImGHx81REvY5e7102YKJaMsPLWz/pa7C8
iKqS449PS5gJMyx+3oro3Wt1+ucRE2CGg7ocja//rZDGtdzZJa1yjFwyw+Ln
sZBGVwX3aX/WGGa4WZ9wx862hXRW6+m4tacmwQyLn9dC2htyrNuT6cOkn99C
hvXvHJodfHouNZGnF4VEmsAMi5/nufR2XJaqx6tpMMMt6xvUPufS77nm+8e2
7yWXzLD4eZ9Lt44OCbkTZAIz3PV7cpfvyQUUtOFZ9aj7M2CGxfWggFJ9tRYc
bPSLJTPsua9689DCfMp5NTeqeoOxWjLD4nqRT8UfetadmzkLZvhucnmE07Y8
+jxhrv34bV1ghsX1JI/4i0N8i/YzpetNHsNNltTLtrg1h14cfrh6wUNTmGFx
vZlD63cXPo6aNgxm+IE6uZ5G8znkZVN8/WiZkVoyw+J6lEuKhpvarx+rhBme
3fHF7uRZubQ50namV7sJMMPiepVDjY6+s9ROnSpdv3IYPuLq4/R+YQ4lWB5e
u2qCGcywuJ7lkM304AUFTabADN8e3nJe/ptsGrD4uMa9HAO1ZIbF9S6bjpll
H9rzwAxm+MHLG792GGXT6NtP1VtTpsMMi+thFk3bqxNsvH2sdL3MYnjTJ98W
5VuyyOOz175PWiqYYXG9zKKISYl9Jp+dBfM//++RRdtt3ZdefDdQLZlhcT3N
pHoL3Tvtu2MGM3xqTVSycU4m+U7T3P/wvgJmWFxvM2n46ZLNK15rSuuJTIaD
kpvYPaibSf797s393N0MZlhcjzNow1C3/b6dVDD/s1dye6/kDErLOJ3ff0YP
mGFxvc6g33e6aya+VUjrkwyGG7a3ckpukEF9e518MKCpBcywuJ6n06r2Bl5H
mo2GGX5rlTzkSn469T++aKj+OFO5ZIbF9T6dGkwPPtp3iSXMcLvvj15pdEon
7WrtbSO9J8EMi/tBGhXMN5ubpG0s3R/SGLZlZemN7WkkL3gT9eOAFcywuF+k
UdDYs+9iFNNhhn/ednH/Pi2NPPzmtz1zdZpcMsPifpJGE4/VLRvnYA0zXHfj
k0MDHqWS6pds7+HGpjDD4n6TSto7on4Glsul9Vwq//OY5DZjklPp2zDjSX+j
rWGGxf0olcpzbk1/P8UMZphb9p/xuEcqDdC6uirnxHC5ZIbF/SqF7Jd/d+vf
0BpmuHRAssnP0ylkkzp++0IDC5hhcT9LoUtrzU4nRLaR7m8pDI/sk7zfNDSF
2nom1av4bQkzLO53KdQ96XKz+NdWMMNRP7sl7+uSQttPn/TL/9oLZljcD5Pp
Ze7ZzNGOFtL9MZnhTsmrtja8mEwJ/o5BnoNsYYbF/TKZYnqVzH0aqg8z3Fo7
uZV2cnLt9dF9ZvgAlVoyw+J+mky6hgEvy77ZwQy3OjWy9plMQ38UDhrXYRrM
//y/RzL9TIlrpO2rkO7HyQzPXfrM98ubJGoy7cTYq6McYIbF/TiJ8qYuLnnu
OwtmeH1Lr8bJ65Jonl9oxH4jY7VkhsX9Oolq/rRadqLKAWb418YPV0xckuiy
05RKpdwMZljcz5Po2LayAq0zU6T7exLDmvXrJsu7JtHA/c3Tsx86wAyL+30S
hY0Yu/Vwa0uY4WqNX7JEdSKp9Je9mvxljFoyw2I9kEibtn2cHDvOAWY4eNKM
5e5TEsl/xKqFsSU2MMNivZBIreU+Z4Zr6ErriUSG1W9kZRrnEuhm8ImPq57Y
wQyL9UQCFU4c/HnHVnuY4bCnstPjLBPoz/vpek0q+8AMi/VGAn1efGfCu/s2
0vojgeGcjO+PbzyNp/i45kd+9nCCGRbrkXgqmGhhsTKKYIZHDNiv2hsZTzND
LAerhljJJTMs1ivxtOH1vknRfZxhhsPUAQV7msZTcvs+JmmLp8MMi/VMHDXV
rMp5WKVSS2a48KFDg7I1cbTh8pGN/recYYbFeieO/shnGhlsVcAMV38/Liug
OEp7vejqls+mcskMi/VQHMmaldZPHuwCM/ytYUl2/6pY6t9t4t1HzhYww2K9
FEtOZ2YZuTaaLq2fYhnOHX5ngl98LDU68Oh9lz4uMMNiPRVLW3ZONL10wQZm
+HaSn3xU11ha3+vL9FkZE+WSGRbrrRiyygs/tfmgM8xwx6ATOkEnYujAi4op
0245wAyL9VgM7XOrCpvZuodaMsP+OpfWyfxjyGBg3orS104ww2K9FkN9cs/5
3BvqDDNcd2bMj6vtY+jlTu0OATV6MMNiPRdNOUPG5zsGOkrrvWiG6658Muvy
sWj68Ojy0WlbXGCGxXovmlLMw4yv5RnADIfsb/r9SVA06ZqYd1o61U4tmWGx
HowmKrvmOP2SK8xw30eXpv/sGk3nusfm3XpjDDMs1otR5NdsubaPm5W0foxi
+Kr2kDzZ1SgymhNQ6lDiBjMs1pNRFHpmgyq+OdaXUQzP2LG5+mlGFJlR2qBt
tetByQyL9WYUhSmO7T9f7QYzXHVkV8yC8VG0rji/oX6gNcywWI9GkSqfFmhF
mkjr1SiG5Ymy3w0+R5LDF93Dz++7wQyL9Wok3Wspi34d5QAzfPzNA83uWyPJ
e+mGCUPGT1JLZlisZyPJOPm06xgHN5jhnRtHPKn0jKSjTyfm22Q4wwyL9W4k
Tchb1rX0uZ60/o1k+NC9aYl6PSPpZsSy3pt9XGGGxXo4kvx/fZ+xOeOfGT45
erLvt4cRdOhj58JcRV+YYbFejqDiIt+Vqxu6qCUzPDfE7PL4lRHUcFf54LeD
3WGGxXo6gqIvP25hO2gyzPCP7gqfN84RtKv939mao5zkkhkW6+0IyvAc/6tr
hAfMsNxFFlnTI4L6NfDY+EfDFGZYrMcj6OeYXsMS/thK6/MIhp+3u7Tf9nk4
1XzPNGw92xNmWKzXw+mSW+zwJGus58MZVtvIfBtsCafiDiUVo25YyCUzLNbz
4XTXoOmK5bs8YYbH+ZqOfxscTulDeif29bKDGRbr/XAar7spM7aRQpr/hDP8
usVno0Zjw2noN4vVHxd7wgyL/UA4Ney8uZWPpjPM/2wqq32GU9S7sxvmu0+V
S2ZY7BfCaMiLrekH63vCDAds75W5/0wYxa0rKjy20BVmWOwnwihz5tqftqmD
pf1FGMOel3Y9HjsvjLx2W6TNfO8OMyz2G2GUGrtjhs71f2Z48cUvJ886hdHc
S03v0UM9mGGxHwmjmyteTNth5ybtT8IYzuxyvZfHwDCa0uPkypPbPGGGxX4l
jFqsjJr137IpMMM/2+wg2c9QGj3V3PCAwkUtmWGxnwmlxsbzntzQ9oYZfr45
ds2806H01u9LUFWyAmZY7HdCaUObFbkvNztK+6FQhl0TtQfoLgqlqUMnBDlo
+sAMi/1QKNle/dO4R74VzLCRxr1Ped6139/tqaN1n1urJTMs9kuh1HZfT7fT
YT4ww7sOWdo+GRdKrhO+jog3doQZFvupUBr3SGe4c4CZtL8KZXju5SGyDs1C
6XCiaV0tKx+YYbHfCqExuz1lemddYIYXJM1U93oQQh3XmFQNZSO1ZIbFfiyE
dIe1bNdsuzfMsLy/bGv93SEU0z7s19jV7jDDYr8WQk0si+cuCxku7edCGG6z
I6v1jqwQmvmu6yfbaC+YYbGfC6FGw9xvN+z0zwx/KEoK6u4QQp0nHp4RuLEP
zLDY74WQX8M3DcrKPaT9XwjD9w8tjrIYEULdB7d4uE3PB2ZY7AdDau+mCyw/
3J0KM3xb7dnUsEkIuc4p1zgR7iaXzLDYLwaT5RSHepP2+8IMh+0n/fePgkl3
S9HOt4+VMMNiPxlMm/MrM/X3OqslM9z37TT5jIPB1DLuxDdttR/MsNhvBlNw
9PMntMUGZnjpqjlJZiXBtDHTduLwZvZyyQyL/WgwRTxet63HaH+Y4ejQSdkN
A4Ipq7vJ57rNnWGGxX41mO4NGK+v+8pc2r8GM6x/vnFzR6Pa12fF2W79tfxh
hsV+NphyU62OFaW5wQwPH2L/3KpHMJluuO1008hYLplhsd8NpvhAr4v17f1g
/ufqPy2r/wRRyeu4dyvWesIMi/1wEC3PH3I3KmO0WjLD86cVbOh6N4hk82eE
7tX0hRkW++UgSl/Ufb2xgw/M8Kllvd482xdE6zo6dG24qRfMsNhPB9G2LqMf
Z3XylvbbQQyrGsnG0rwgsg1v8jx2mR/MsNhvB1FBUeeQEy+mwQxXfDNs3Ds0
iJ65LTdutMpDLZlhsR8PohUTZruMVQXADNcfcfPbAkUQuee3DGk3SAUzLPbr
QfTt546g7ytcpf17EMM6Dl32FA4JovZDK05pRQTCDIv9fBDVb7Jt+84yO5jh
lv97BNGUrmvu9enppJbMsNjvB5F+/JyuqT8CYYa7PuhS+08gVa6Pbz/D1wVm
WMwDAqmiYVXX3DgraV4QyHDrGtkm3ZWBtff/6mENbgXCDIt5QSD1LPn4Im+E
B8zwnrulW1q6BlITk2VuA2WmaskMi3lCIG2MbTkjpnkgzPCexj2mfO0VSHF1
nt+8usIbZljMGwLJ/FbY13a/9aX5QyDDdfOnfj/5MoB+nJl5bsQyf5hhMY8I
oBkTK9aeXOgHM/xadiAmaVsA/Tlhs/77o+4ww2JeEUC9/+u8pHmWr3Q+EsDw
E9MFa3XCAqhy78t7Gs0CYYbFPCOAZlcEVPX6zxBmOFSnMrpwXAANavY0xvOG
l1wyw2LeEUCzLCvbzYgIgvmfH8hqnwEU1/jaFn0nc5hhMQ/xp60XTg5qWewu
zUf8GT7TqbRSdsafXi6zD9BuFwwzLOYl/rTe+Rqp1jjADOckdu7xscif1J0V
9t3POcslMyzmKf50tpHxlnv2wTDDu0LCk7bY+VOVZ8TuX4ddYYbFvMWffnz2
jM7tZSudJ/kzrGP7a/WAPv616487GyaYBMMMi3mMP1V2C/P6fccTZriCp9gF
fPSjvopH9yq+KOSSGRbzGj9aOfRC9KqHQTDDz8/K5vsf8SOPQ2tj9hT6wgyL
eY4feQ43Tu7hK5fmO34MT8r5adM7149Ob21gaNUxCGZYzHv86HreqMaqcwEw
wxnTm10usfKj9XqtTTM2dIYZFvMgP8r33buq6w9/aT7kx7Bu6aCxe3r70b3X
fm3mHwyCGRbzIj+y3Op45Ye/Ecxwbl7Gu9QvvnT30ouV3NpXLZlhMU/ypaut
PlwvUQfDDMdOzHL//Z8vfRlZZmoUYwEzLOZNvnTgdHpzzwJPaR7ly3CPv9r9
O8/zpfuLtnfuFBACMyzmUb4UvbdQry45wQw3eHfk8SN3X2p19PzQkARXtWSG
xbzKl/SO3f9x9UgIzPCFhrdmGI32pdVLnN/Ua+gOMyzmWb7UcV6d6h9P7KX5
li/Da7rfHjqzkS/N3d7p+NDtITDDYt7lQ1v63yo+EekNM+wwtyTxxV0f2rfQ
81eXuiq1ZIbFPMyHzP8sarx8QgjM8O/XmYM7bfeh6Cbxr3vG+sMMi3mZD+mS
ou1bzcnSPM2HYeuHQxTPUnxo+aHW2ck+wTDDYp7mQ8+unu3tGRcEMzwjx0vD
wNKHHsUPvXH1ZzuYYTFv86FOhxJKTMYESfM3H4ZLdU9k9hvgQ78Gb9V7+DYY
ZljM43zoeLVeWr9nRjDDOqWy2mft9/diTtwHC3+5ZIbFvM6bVj4bvvGFZijM
8EAvX60VN73pwuNzBj3jLGGGxTzPm3Zndf/5oKR2/yfM8J2W5q96bvOmJ4mN
6jWoCIUZFvM+b1qu8+H47K7OMMN/1fnNBqd7k3qOumEdfXe5ZIbFPNCbrkye
aTinSxjM8LbIx00O2nnT1nYfDadP9oAZFvNCb5rUR9XD2t5Jmh96M/xswJLE
ihHeZPWn6+PTrcJghsU80ZvK+pzsfLaxL8zw9bmy1rObedPA88vXdOltIZfM
sJg3elH8ta/eHZeEwgzT6A8xymdeZPCgXXFdu0CYYTGP9KKt+z+fP3dzqloy
w+P+uiRdYC8yabL4SN1DITDDYl7pReltaUGjgmCY4aXZsq/qRV60d3Pb508S
NWCGxTzTi04qNZoOjAyW5p1eDJcXqQ/1CfMi9X6DNspOoTDDYt7pRQvWjOu2
esB0mOG2DaOO1ZntRffeGIdUrgpUS2ZYzEO9aEPqWeuhs8NghkvXpMhm9POi
8OdWNuXuVjDDYl7qRYvSShKdV/tK81MvhhtqOyXJGnqRT/yqYQd1w2GGxTzV
k55/qju27ldnmOFOs20UvR55UquA0o67ZZ5qyQyLeasn9Vlj5/oxMRxmOE42
qKjsiCf59NQ7vDfcE2ZYzGM9qaHGns2GV52lea0nw7lj9/puWuJJvu4GP6vD
wmGGxbzWk+5dS+v8qdgPZrhZxeJWmtGe1FLe5MxmZyu1ZIbFPNeTLnVo16Fh
TRjMsH+47NgZC0/q2jFrgdbiIJhhMe/1JJPiW+fX3jSS5r+eDOf9MThRPcKT
BoQ2dTrVIgxmWMyDPen7pxa3/y4LgRluFLfUP6qNJ41VL7+d9SqdJTMs5sWe
FHdKL1e3PEQtmWEtp4/tnT56UK92G65cnx4GMyzmyR5Ud2fDa6YG02GGnU8l
91532YOqnvU5N/hnkFwyw2Le7FH7+Xzyn01xOMzwBJ3Vjafv9CDV1yDfj6Os
YYbFPNqDxtRPOnn2gL80n/ZgWH0pa5xhoQetP/n6Qr+QCJhhMa/2oM/BA6c0
UrvADOt4ykatCPag8tsxUyOueMklMyzm2R70X0LHzh/uR8AMr56hnz5b6UED
x7TZPmqZF8ywmHd7UJ+UipyRKlcpf+LB8D11zn6L4R7U4E7zr4W3ImCGxTzc
g4p73G3co00AzHDJtqFeZW09KKJBO9+Nu23kkhkW83IPinsclTXdJgJm+NfA
viPcvrrTp2nZL08kB8MMi3m6O31oGjbOWtNYmq+7M7z20Zvjnrfc6UrUmnNH
3MNhhsW83Z0OGx8tGrMxFGa4sMaw4tABd7IbszLW/HRjuWSGxTzenUL73Tze
6E8ozPCmcz0+OC9zpwUjQlOsQ8NhhsW83p3W/ThwvHvP6TDDTg2sZBZJ7jRh
48TbW/RC1JIZFvN8d9qV73TX9HoEzPAjZdyBBa7uNKL7lQkH31vDDIt5vzu5
fdArrXs3UDoPcGf4T8rBZ70M3enaisn1qSISZlicB7hTK6erWuYJrjDDMxts
sPjbz5229zn8fuBWH7VkhsV5gTu5TEyYHkpRMMMn/mv1sHsLd9I0nPuurNwb
ZlicJ9S+/4M8DVs8cJPOF2rff8lLjKtcCj650cGav3sXjI+CGRbnDW50YFBd
lmcFwgwbD6g8MvmWG0X4PS761dleLZlhcR7hRq2+btC+fDASZvhhwbqqiYfd
qLv/68+/3EJghsV5Re2f7ymbVOE9WzrPqP3zJc+QRWxNXOVG/veazrxyOAJm
WJxnuBH1VxWs2hEGM5xkJOveIMuNltZxdH9qrKuWzLA473CjufOdDR9NDYcZ
9nCyHnHB3406R7yzObMoAmZYnIe4kfmEN20bXzeCGT4TcfLRbTM3itaYufia
dahcMsPivMSNJrZIXPW3bRTMsMm7zUP6jHOjPc/mF9WZawMzLM5T3Ei/omz8
Z1mwWjLDCmuH3nu6utE1zQ2NH2tHwwyL8xY3erPiod2NIW4wwx7uzS+naLjR
xm6yTscK/eSSGRbnMa6Ua9flgOvyaJhhje1rJxW8c6XRL+sf7HDWB2ZYnNe4
UvBX06/qCA/p/MaV4YrwTYW3r7vSGv3eHd+WRsMMi/McV9JfMWnCouggmGHz
vj1uOx12peyLE22ySh3lkhkW5z2u1GHaPZ2sztEww91PxYzpudaVIv10lmyd
HAozLM6DXOm0z+FmT+MVaskM52t6XO2e50qLvms0fq8VBTMszotcyfFX5ZEB
u8Nhht9NPX3ZNtyVThnUMV/n3FsumWFxnuRKH5s1zyyeGwEz/L3fCscL9q60
7z7vbHc4EmZYnDe5UveNQ1/9MDOCGZ7W5sGW6Gmu5PNsXbf5+WFqyQyL8yhX
aqObN8JMGQ0zXNPJ563dYFda+d/LHju0bGGGxXmVK2X9nF22XSdEOr9yZXjv
65dWkdquNL2vd++6PjEww+I8y5VMtK2HJ9x0gxl2qvtfv1MyV4rmSs8OSQFq
yQyL8y4X+l700XDrrxiY4ZmX/6yc9dqF9uhpHTe77AszLM7DXMi/6tC4Udpe
0nmZC8OlpgNlja+70KXpj37ENYiF+Z//d17mQh08Wwe/7xsMM9xqtE3+jyMu
ZH53fNgCXWe1ZIbFeZoLRX4uu2ydEgMz3ODopyLdjS409FnbV6c6hcEMi/M2
F8o2vFqvq6OZdP7mwvDa+vttQ4pd6Idaq5ssLBpmWJzHuVD+aq3RFWURMMMm
F1aOqYl3odNOHn8Pug5WS2ZYnNe5UOrkvdca34uEGe4juxFX5uVCk6Oza/Sq
omCGxXmeC+nq7HR7XmoIM7wrsjBhmZkLLRi82+ZBRbhcMsPivM+FWr/NPzo6
LwZm2NZJa8G+iS50x33H2v0ZtjDD4jzQhQ4b3itYMzpUOh90Ybhf69Lusn4u
1Mz87obM8liYYXFe6EIX21wfNjHEHWb4mblRUnS72tcv/Y6s2fgguWSGxXmi
CxX/+HFhnE0czHDrrrLapwv998e516xzfjDD4rzRmXQnNDa0+c9byrM6M2y8
P3H85zfO9KN0Ya9hPnEww+I80pn4pE1S++vBMMOHZwzy/HLLmQJXDTngFeYi
l8ywOK90ptKjN4OHPo+FGbZ+oPur+wlnunTqna78UxjMsDjPdCYzjQ4bk6zM
pfNNZ4YfH/joGbfTmd6t7F34+XIMzLA473SmgLCa4Q7bI2GGl7d60EG23Jlc
U1326c8fIZfMsDgPdaYhLu6uIwdFwwzf7T83dUeOMyVWZJ/88OOfGRbnpc5k
1WjpmtMHp8EMp93o2CEn0pkm+Pk1XlU3Ui2ZYXGe6kxfGrwuWHQiFmZYNuyX
aZ6bM72eMriiUZUtzLA4b3Wmspx2ycetwqTzWGeGT1//vbpc4UzNyjU/OGjE
wwyL81hnOtekua+mzANmuKfhiLzm5Ewf2565d218sFoyw+K81pk0m/4c/G1v
PMzwFvXb7NwBzqSM6R385aA/zLA4z3WmFx7eVVqxvtL5rjPDvY3Wdxii40y2
szz8vl2IhxkW573OdHDonx51Y0NghpNayo781HCmGeGLu2+46aqWzLA4D3Yi
9ccD3WuM42GGV/Uqq3n7xYmOpCmX1v8vHGZYnBc70YARARs/eltK58lODLdy
SjFv+MSJtn4dMnXP0DiYYXGe7ETcxEj7yboomOFxy0daTLniRIMa+Qw7UzVW
LZlhcd7sRFYVXw3rJMfADAcb5GasVztRgq3+Gfs2sTDD4jzaiTw6Lzu9aM1U
mOE9bwaFDN7uRKl5Hy6eNoiSS2ZYnFc7UYZl299uP+Nghp1St6+7u8yJfK+u
HVSiYwczLM6znWit0TvN3/HhaskMP3IPL9s8p/brr3HxCzVLgBkW591OtOWu
ldvFVA+Y4Uev9vddEetEWROS/1hMCpFLZlichztReeFwxfnWiTDDP1tHL93j
40RNcn6sG1UaADMszsudaMW2bFPr8f7S+bkTwxnhIaXvrJ1o193rC/cNT4QZ
FufpTjRi1XGjdR1DYYZPuLU/N326E8k2X7GeOs1dLplhcd7uRGdWT/67vCwB
ZviXYcq+ijFO1P95nb8atetJyQyL83gnanHXcp9TsbVaMsMv+0b+ctNzovfj
3rceXBwPMyzO650otF7XAMPF0TDDo2MUo3pqO9HDqLcq1yySS2ZYnOc7UfN1
e6KtbsTCDCfVkdWtr1n7+c/8dNWmbxzMsDjvd6KLbqM+KW2nwPzPf2W/NKod
6UtVl17T0qLVkhkWeQBHst47PCFjUALMsE/zlSWGlxxpu87j1OlkBzMs8gKO
lPOzR7zB+ggpP+DI8NiX11tW7HCkrT4hC3YsS4QZFnkCR/ph1b1rRo0HzPB2
/eS9KYWO1NQ3+FG6cahaMsMib+BIhUMzW1wblQQz3NjM8UJciCNNcg8Y+zcq
EGZY5BEcaeSNGWmamoFSXsGR4Vlda1aXmTnSokEzygcZJ8EMi7yCI52cc7TF
t72hMMNv5ixJ7z3SkcxM/OcNVnuoJTMs8gyOdEZOuenNkmCGtbrI/7vW3pGS
F8xuPN4yEmZY5B0cyfDUmjm7r9lK+QdHhre+zi47/N2Bsp4mHTT5mgAzLPIQ
DvQ8Pv95ZHYMzPDaq2UbH9xxoP3jN6W+OzNJLZlhkZdwoC2rf1/pNygeZrhp
k/S/4w87kEWLpBs39P+ZYZGncCDnbi0NPt6fBDO86PmUlldWOFBn7W6ODc7E
yCUzLPIWDiRfdan0lUMizHCjL9vGrkhxIKsrVzx0Z9rBDIs8hgMlHtmnkXwt
UspnODDsa/L87mp3B6p6PeVvndAkmGGR13CgxcaeHbq6e8IMlwwPtL5v5ECt
X+rdMbMNk0tmWOQ5HOhIPb9p5Y+TYIbbv+ugpRjgQI4n72V07hEEMyzyHg7U
8/WYSI3AIKn/4sBwnYeyuO8tHOjQrOL73n+SYIZFHsSBvEefvPDCOAxm+O6T
+A/XPtmT7X/qEvOpXnLJDIu8iD0FhOrtLTmaBDNsfLv946c37enq8HW7ijpE
wQyLPIk9RU/t8PrGQAcpX2LP8LXg+CP9DtlT7ucmEQkDk2CGRd7Enjqk6Ti6
h8XCDBvoJ31aVWpPY3jXkvr1psklMyzyKPaknFbZyi0rAWbY/Jbss0m6Pe39
cfwJz/hnhkVexZ6OTRlzNWKYAcywUdj74f197Knv8jrbv7SOU0tmWORZ7Kly
y6EGNC0JZviM9+i+42bbU8mLuuF1JtrBDIu8iz0dnB22fnODaCkPY8/wiE7q
mTEj7GnC4rEr+rZPhhkWeRh7OnFab2rhcU+Y4TWaju1ed7Cn2c3+q1cWEK6W
zLDIy9jT2aLyM03mJsMMq79flM35a0eKUSMmvk8NghkWeRo70kvccbafY7CU
r7FjuE70lny7p3bUf+jslSk7kmGGRd7Gjial/9cyqCoMZnhcgKu+3Vk7Kmwf
tHLtdW+1ZIZFHseOyje3i/8Yngwz7HRvSHbOTjs6olnT8c+NKJhhkdexI69+
hRcsZztJeR47hk2etPv5bIEd1fgou5Q8SIIZFnkeO3o4zOzW39r9rmSG5124
1C44wY4MNvIbG7/paskMi7yPHe0wK7tV/SQRZniy13VHPXc7OmlvNry+xT8z
LPJAdvTmw5qS42snwgzn+0x1bmpsRwkX5N0bOMbLJTMs8kJ2ZKQzkuffTYIZ
jm7/crXucDvqEtVt+istO5hhkSeyo/HuoUN2jotRS2Y44kufMisdO1rvPbeu
0f5kmGGRN7Ij+f3K1hfaecEM66pltU87injsaDwvI0IumWGRR7KlIOeGnY/q
p8AM13hr+Ctf2pLt/jd6L+8FwQyLvJItVZR557moQqT8ki3DexWqUS0u29Ke
R32cAlxSYIZFnsmWFgwcMj/ZKxxmuLgks9HX/bZkWf69oFmwr1wywyLvZEu9
+t2zLOmXAjOclXY4uuFKWxrubLQ4qCAaZljkoWxp8jCjg0XFzmrJDOvKszvK
s23J7pzBMvuSZJhhkZeypUFltkmjJ8TDDI/wfZe2Krj29Vn9PexGQxO5ZIZF
nsqWrOsF3Ly3MglmuIumrclAm9q/f6fMpqcH/TPDIm9lS73nBhf4pYyDGdYI
WtnswSRb0g4OXt1tW4JaMsMij2VL2V11XoUEJsMM9/D56Higvy311wuNvXjL
FmZY5LVsqdR0jXFyaKyU37Jl+JnTzfsH29rSk5aDGimtU2CGRZ7LljauuOt3
1tYLZjhl94B+T37b0FvL/KA3qyLVkhkWeS8bOtjLq+LCsxSY4Ub9dKuGPbch
Y4+k5/VGBMMMizyYDe27Y3Jt1axQKS9mw3BxhNbC9ZdsaJfJ8fjubVNhhkVe
zIZO2vqZt34XDjO88+mVnwYHbKjvu8nqGC1/tWSGRZ7Mhq4evVweeD8FZniN
jnyTbI0NHfBpsatyUgzMsMib2dDDA1v6FTx2kfJnNgxvfp017VmeDfXyKtl0
ySgFZljk0Wxo0o/wbb90EmCG71g0Dn8faUNNkpd2HOhtqpbMsMir2dDogrVJ
tspkmOH7BbPv6rrYUEHvKo0tO5JghkWezYYm7+lw92PNSJjh0b2bdQ0wtqHy
pa7xunWS5JIZFnk3G0oqGCo7I0uBGR44Wff1o1E2VPbRYNW6JFuYYZGHsyHV
O7O4JjvipHycDcOD/4Y/jelmQ9W645ZO+JECMyzycja0Of7U/oR5XjDDH84P
Kh/Z1Ib+VJ39tfF4lFwywyJPZ0Pdtp+f1a8wFWb4Up2QVm2+WVPhja+q0anB
MMMib2dNPVqUpdw3CZP6tNYMN3aMX9z6kTUFf+xkV3IiFWZY5PGsae6evrFa
AREww/KrS2UjzltT5gb9zndOBcglMyzyetbUoaR165iSVJjhywN7f4nYb00b
Np3QHvkhBmZY5Pms6YLV0EIiNynfZ83wwp9hPe+utqaAu54/Hv1OgRkWeT9r
0jSc84Q+J8AMlwY9I6cCaxo19u0yV0+lXDLDIg9oTW4PFhc+qZcCM6z0uP69
Qaw12Vab2KwakgwzLPKC1hS4KPSwW4uhMMNqv/mycx7W5DvAxnPppiS1ZIZF
ntCarjVqlVdUlAIzvOBdaLNdSms6ajJF6dnCFmZY5A2tyapyT3uqjpfyiNYM
W3tuurRvojX9+Bq+rc7CVJhhkUe0psrv325WHfOCGQ7b7Fanqp81WeR/NeEX
0WrJDIu8ojU13GJleHpcGsxwlcF+ZTcta7L/NTQz9lwwzLDIM1pT5N0jU5sq
w6V8ozXDRy+sTEirZ01vVz61L49IgxkWeUcr2v3fKZ+MFxEww3UKZOMbVluR
PG5oqzmTaveDwgyLPKQVtf7w7uyG6Wkww5pPFkxeV2lFf+qY7vFbHAszLPKS
VhRSpvdy3jp3KU9pxfCh97LZbqetyNm4ZHhOWSrMsMhTWtEq//KLH04lwgx3
kO/Vlu+1oiXRJ43+xKvUkhkWeUsr0plv2ydobwrM8Igcmd3Y1bV//3MZbqu3
JcMMizymFW1yW/xzQ2IfmOGZYfWuz55rRW7NDZSZFslyyQyLvGbt1+8b1PN4
t1SY4QUBm+Wp8Va0ePevzo3TbWCGRZ7Tiu5+DpjRZESiWjLDaYv32F31saLR
a4vHF45MgxkWeU8rSll4uc/9x14w/7N6/XOysqLUAxWFnVrHyiUzLPKgtV/f
eN/UlY/TYIb7Ki6Unppa+/mYNvriqRYhMMMiL2pFX+PPzNO1jZDyo1YM94wZ
a+Q/3IqGjbn2LKNPOsywyJNa0cij5UdU9pEww9ryA8sHdrOiJzVjvFv2DpZL
5n/+36P282OjP/vDnzSY4bOb77s3amFFESMjSiMmxsEMizyqFSXtGVqW2sFT
LZnhJNlnxzq/LUn/Vb2fB73TYIZFXtWSujz1XJNsnAQzrN+gZnbr15Z0tF6v
9a+3WMglMyzyrJb0YdFB5WfvVJjhaTM3/Zh425JGz8tdtK52PS+ZYZF3tSTb
66eKnIdqwwyvKAnqlnHSkjaeCa++Wi9FLZlhkYe1pMPjYvyU21NhhoeP9p7z
fI8l7cxrtSTroTXMsMjLWpJTWsuC7ROSpPysJcNzCh3quK6xJKMpc0yeXk6D
GRZ5WkvqO3RQSvR3L5jh49kVk78XWVLPj0Yn91CcWjLDIm9rSfcPxz9dn5sO
M5yipe60PtmSbn2PKNcyCYEZFnlcSzI/fWpvPe9IKa9ryfClWy0tAoMs6a1Z
Y7uPN9NhhkVe15Iiy+8YRZ2LhBmO29l9j6mjJcUW1zx43zxELZlhkee1JO/1
W+pM350OM/w0TFZ/5ixLSm5i0WtaVRzMsMj7WlIfv/VffyzwkvK/lgx/W2TV
1GGCJdltb/zKv2s6zLDIA1vS2PjATcN2JcEMd/kRtDB7gCXNKtI16vDZSi2Z
YZEXtqRP6g3anp3TYIYblwwKPd/RkralyRJXr0mBGRZ5Ykuq/hl6O+vVWpLM
cI1Hc6++TWpfnxV2T6J21e7HhRkWeWNLspzbpcNo/TSY4aTJPScvq7Ggsz7L
rKp6WsMMizyyBXV8Hbu/7eMkKZ9swXDYbu3Leq8sKHfU148f/dJhhkVe2YKc
QnZNWFPHG2b4/ave98/etiDHCGuOCo6XS2ZY5JktyDol8dSVYRkww3136+hn
nLYgw5OtmjunhcAMi7yzBeUs37p/d2yU9Ps3LBiuFzWrzLLcglZo+vT8kJkB
Myzy0BaU3O5a6+cjo2CGteQb28s3WpD3kKhGXX/X/nnCDIu8tAUNmDxs0lrv
DJjh3ieXjqBFFlR1+9rRCxHxMMMiT21B9wvbTnrZzUfKV1swfGBujypVtgXV
dT1SPO9mOsywyFvXvn/dK4vS2iXDDJ/U5AdJ0RZksNGdQ81s5ZIZFnlsCxp+
PiHkyNU0mGH55vCWx70tiOOitxbqpsIMi7y2Ba3ZV3HhlpaO9PtKLBi2HH55
QkcbC0q9vk3t55IKMyzy3BY0xcPjreeJNJhhxyuV47JnWNDS0siX9WZbwQyL
vLcFnViyJH5ATrKUB7dgWDegx52m+hbUVsN2+o6GGTDDIg9e+/6U9xpk+csL
Ztjh2dZ3a/tbkL52t06W6xPUkhkWeXELCl+ot0DrdgbM8AlnmbFK14K0Vupe
XrYnBGZY5Mkt6NuvG5Hdi6OlfLkFwwtXdqrQamZBt7M+bIganQkzLPLmFnQo
JNRhwaIomOFAu9ih1b/NKX7OJP351aFqyQyLPLo56eSYhv7snAkzXLaisWvV
O3MqWNWiT/0mCTDDIq9uTlVHN2022Ocr5dnNGd47euiQ+/fNqc+tWWl6BRkw
wyLPbk5vb4xpFhSRDDNs2fl0wJdL5jTo1+O1z87YqyXzP/8v725OW8/bzqrO
TocZblDd+UuXY+YUe6L8kldRKsywyMOb054TFye2PN1PysebM9zWs3qRQ5k5
JRed1lzXJg1mWOTlzamB9cGDd03SYYb7V/mM2LnGnNYOD7//3dESZljk6c2p
zWT3Pu+G1a7fhRm+cKXvUq355nT295yoNisyYIZF3t6cwvueWJPz2gtm+ELc
yI2FmeYUkVBsYfAwUS6ZYZHHN6fl0Tfq+CVkwgwXWcpGdIk2p+/ljyadfBAC
Myzy+ubUcV3kMtoeI+X3zRlup/apfZpTo4p25gnPMmGGRZ7fnOZer78u8VsU
zHBG0b7eYXbmdLHNhfmGL8PkkhkWeX9zChkf+0F+LRNm2ONCiYH+rNr3Z8Pp
sXcWJcAMiz6AOT0xPXz5o6W/WjLD7eT/94859fN0MNA1zIQZFn0Bc2r28NP9
t9eSYYZ3Dt7xSzbMnKKGdzIZNNBJLplh0Seoff/vhBV8lGfADPdsJ1fKeprT
MH2NDV0bpsEMi76BOU2TlR9JWzdC6h+YM+yskOm2aW9OJ3r9HtKxIg1mWPQR
zMnAx8Aj+1o6zPDSN3NHjtY0pxbaq86VW1rADIu+gjlVz3/12rQqReovmDMc
Z/06xr9GRbNcfpW1HpUJMyz6DCry+10UNPqCF8xwzwm+p/a8UdE6z8g7xQVJ
askMi76DityeDzl0onsWzLBs/KmaFvdVFHei14MbDUJhhkUfQkXnFPVK/1yM
lfoSKoZnnW33PvayikbV67TgW0kWzLDoS6hINWjT0vmzo2GGe2gcS/lxXEUc
fbp+3+fhaskMiz6Fimo0grR9s7NghnXzSoqz9qpoWNzt1lN7JMIMi76FiugU
3X1dL1DqX6gYtrPd+ldvo4pWrrCZ4fE3E2ZY9DFUZPNn+YuvQ1JghmW7U9fe
WaKiiAO7Su8nOaslMyz6Gipqoefb/OD3DJjhy/Wfui7LV9Gq1/4Nd0amwQyL
PoeKRvRNPnN05nip76FiuNfVTx2Ck1V09kLl8mPR6TDDou+hoq5F3e57WmfA
DH/c3Hu9eZiKth0LmTx1lDnMsOiD1L5+o1a9m5mdKvVDal8/yS+1DF/P8FTR
IN+m+mvOZsIMi76IivZ2XXXPYo0XzHBBcVCFqY2KrOyX94sfkiyXzLDok6io
OiMlU6ciC2Z4cm6LDp4mKjL3sHOp6BkKMyz6JirSDlp6XPElTvp9XiqGu9s+
OJ4nV9E4q+gHtydlwwyLPoqKPg7aOejqymiY4d3Kd+v/G66iK7KIUYNfRcgl
Myz6Kiqq6Fk4KXBiNsywyaGidU36qKgko+TvmPWJMMOiz6Ki3X97HMqzD5L6
LSqGu70IXemio6Lvg69r/9qXBTMs+i4qevl2kG5aTgrM8ItxaTGnm6kor3zb
6tgHLnLJDIs+jIr+i1y5iHZmwgy3lctqnyr606XR1VbP02CGRV/GjGIedk3U
7DdJ+v1mZgyHcYhpxWczGl2Tv7FoUAbMsOjTmNHtO7f1Air/mWHFjY2t7V6Y
kXmjdzcW/zSDGRZ9GzM6qLtTfmNUmtTHMWO4so16gqzSjHRuelofccyCGRZ9
HDO6/8v+wCN/L5jh1wvb79lz0Yz2BvmUqK7W3t+EGRZ9HTO6btiqr5NXNszw
z3HmdtHHzejXhXdcMCEUZlj0ecxoY3iqTv8uCVK/x4xhu03eWsb7ar9+9x7r
dKqzYYZF38eMXgQ8Tx7wDv0fM4aTl2ScGbjZjF5HydbN+hiplsyw6AOZ0aG6
8tOTPmXDDAd86m7TeYUZfUvQNbjeOglmWPSFzCjxxfQP+yYGS30iM4a7ffu+
qVOxGTnUqep6NSgbZlj0iczIePq4zPyHKTDD9RMarOqfaUZ96j8Y/HWmm1oy
w6JvZEb1rhd+CffJghme0iezp1GsGZ28PKORviodZlj0kczoQuaipqWO06R+
khnDrYt+a4UG1v79PnVanPwkA2ZY9JXMSL/+HIti+0yY4Z0L9Vy2uJpRI8VF
nYPrlTDDos9kRp83jHj47GmaWjLDtvkaLz9ZmlHpQHNPy49ZMMOi72RGvqkX
TK7384IZvp14q2i6sRkdn1Fd0yoqRS6ZYdGHMqOrxRGBcxrlwAxfjdCatlVu
RnWLggcMNA2FGRZ9qdrXd3tmepxJotSfqn19JVdw/MvOI82oq+snp+1Lc2CG
RZ+q9vW5++bLohExMMOLh8nclvc1o8LKh/Nj/0bJJTMs+lZmNKvBmAZ31+fA
DB+Lv7q0f2cz8unbv6/h7CSYYdHHMqPNwxsF+vYKUUtm+F2oc2xFazPyT7C8
/KBvDsyw6GuZ0aYto2e1GJUKMzzATvk8QMOMHqyXr5503F0umWHR56r9+drU
o8qsZzbMcMaUzFM9fynJNWtSeU9OhxkWfS8l5Yw9EDinYobU/1IyXM9SR+NF
tZLeaJ7enL4kE2ZY9MGUVG/rzDkXKv+Z4fpDHXL3P1XSTs2Vq9ePU8AMi76Y
kqYMyzscNj9d6o8pGf45vmrC/DtK6rC28Rn31GyYYdEnU9K8gFvOfe96wgx7
NrfWSL6opIHf3/ff2jlVLZlh0TdT0t8p34bO25gDM9xGffpS1H9Kml56T3uR
XSjMsOijKcn9wvg7HeVJUl9NyXC+yj41vlxJF+v8ycszyoUZFn01JR0NSOvZ
JjwGZviSdqRmwTYlrd46rP2mVjFqyQyLPpuSHs14OWugXS7MsEaj7dO3rlbS
23qLt73JSoIZFn03JWXl769c3ipU6r8pGU4afXnIrYVK0tOyKdF5nAMzLPpw
Srrb/+DWv5mpMMOrR1atb5GvJN8xygdm0zzVkhkWfTklqfvUrXvxXjbM8O+E
BovMUpUUvuyxxsk+GTDDok+nJPP9W/N2OMyW+nZKhk2fbXu3OkpJO7pYNJ1n
lgUzLPp2Str01/dve5t/Znhp/aDiOgFKGn9vebMKr9kww6KPp6TjAzbujDDK
kPp5Soa1N7UM8XZVktdm2ef7rXNghkVfT0mB+6In3knwhBnupsgOv2elJFUn
7QedTqbKJTMs+nxKeux41zSo9vMkmeEGxXWzHWcpKTL03PALLqEww6Lvp6QX
LrPbrL+bJP3+TyXD25ZfW/Bmcu378/X1tk2fcmGGRR9QSZ4jHj8s2B4DM9xl
Z0Ze+lglNX7T5ud5vVi5ZIZFX1BJNvFX/wxqOQdm+ETBBfN+g5VkGtPRVc1J
MMOiT6ikD1/N1xvVC5P6hUqGs+vPrbzTs/b7r0y9GL40F2ZY9A2VdKp1WY3V
zVSY4fW2lc0W6Cip8mb8LN3rXnLJDIs+Yu3n5+3HplWLcmCGRz3+cN2hpZJ+
Pp0xWCc/A2ZY9BWVNF+1f/3XNkrp96UqGfb30+82rKGSbu9xrVzbNBtmWPQZ
a///B+e+ul7PghnOvTC7suUvBckNPfc87GsMMyz6jgrqets06/HPDKkPqWDY
zffDp5oPCurVYob7odIcmGHRh1RQCtXd/LidJ8xwyZ5m5tXPFRR6efpB2+A0
tWSGRV9SQc0LTuxp8ywXZthg/6E31VUK+uWy2vukSyjMsOhTKkiVWzzPKjpZ
6lcqGA4rlW/4dVVB41zMZ/xaNgdmWPQtFeSS83u85pMYmOE/hg3C25xR0PH9
jZ/fmRKnlsyw6GMqaODGB/7Xj8+BGb5/dIV8pFpBJlGrPh36lAQzLPqaCnpU
fknmWIM+p4Lh4S/Of3feq6BV5pZPnpvPgRkWfU4FzXy/elXbnmkww3Nfh+cu
2qKgbd8j7+QF+qglMyz6ngoqajFweah5Lszwk8drn91dVfv+H6mX2P5jBsyw
6IMqKKly5uWWhSqpH6pgeJ9L8Xe9RQo6Nfvg4G0V2TDDoi+qIJ8lfc5umfXP
DFc2XLI9qUBBJXUG+W/ebwQzLPqkte9vQsjPnTsy1ZIZzmglr3mUrqA3FZWb
PwzIhRkWfVMF9dxi9M6g1ANmuPxX/5Oz4xSk06XK2KFTulwyw6KPqqAy+8aq
8JQ5MMPt2wxqcDJEQZ27X36SaBcKMyz6qgoyu3W5Wq9DitRfVTBco6m/2shb
QdGhHd9EGubBDIs+q4LObLqSGNYafVcFwx/m+8295qigrUtcp/3nHi+XzLDo
uyooX1v9pV1kHsywZzvZIR8LBYUFF+tV9UyGGRZ9WAUNH2X+9ObXcLVkhrd1
sG3XxERBM0JKhni0yIMZFn1ZBT1+9Lj/gIA0mP+5rWzOnskK6nBz/ddF7fzk
khkWfVoFySx2mGS1mgMz3Ll6aQufcQr6E25st9ssE2ZY9G0VdDGj9YR5vS2l
/q2C4b1lPwv0hiroy6w1zdYk58AMiz6ugmY1s33+4kQ2zPC87s1+V/dR0I8Y
e/dB7abCDIu+roKC+gXuvuWRJfV3FQwXOT2edryzglxV71wj9uXCDIs+r4Ju
BN+98KGTB8xww/m77Fe0U5CG3rMWnc6mqyUzLPq+CjoxSKNvbqc8mOFB8y4N
TW9a+/251zT7NDsUZlj0gWuvH4tpWcuDKVJfuPb6IXlT0u6ysHoKOj/+WK82
1Xkww6IvbEqeoXsHnx8XCzPcPfTrVf8aU/L3mW8an5uglsyw6BObUqMhBh+e
9s2HGa7pMzs16IMpdVr8+WlHs2SYYdE3NqVc58WtNn6PkPrHpgx3XrtgV9wL
U3JYX9T82ak8mGHRRzalpHHXRy7akwYz/OzpKWXRfVO6tK5oydCT/mrJDIu+
simVnlm6ueWFOTDDPzJ+qnbeMKU3ujaT3uzKhBkWfWZTupGw1zP4mrXUdzZl
eEqo56bb501p6eDRwfETcmGGRd+59vWbse9UC/0cmOFPha5TmpwwpfOHulyK
JAOYYdGHNqWoGk/jWZ2zpX60KcPe4e5tpx0ypTK1fIyBfA7MsOhLm1KT5oOK
q/PdYYbHNpE1zSkzpbBXMb4FMRlyyQyLPrUpjXoXNX7mvjyY4fYmL3RvbjIl
2tZvju6EUJhh0bc2pcHHDv7UcEyVfp+4KcP88dWYgatM6bv9mfzjC/JhhkUf
25Qu+y5q1sQ+Fmb4es+vijmLTGnH+c2aP/YkyiUzLPraptR2xrZD4yrzYYY3
DWlr83muKTU2XdY/LCEZZlj0uU3JvtnQZqf+Rkr9blOGv433m+yeZUoJfZdc
t0vJhxkWfW9T2jaja7R5TRrMcNxfgzr3E02pIGSG0dS0QLlkhkUf3JSSM3Pk
dXPzYIYzQr+kOEeaUrtNS47tbZEFMyz64qak3SD9cuFiO+n3q5sybF5Y98ib
AFPq0H/n9CE1uTDDok9uSnvLjf5qb8uBGfZqKFuT5GFKaYv8jw0MHAczLPrm
prThca5xo5vZUh/dlOH/B1dx2Qs=
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     StyleBox[
     "\"incremento\"", FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    FormBox[
     StyleBox[
     "\"rapp. incrementale\"", FontFamily -> "Helvetica", StripOnInput -> 
      False], TraditionalForm]},
  AxesOrigin->{0, 0},
  PlotRange->{{-0.011408221408221408`, 
   0.011416361416361417`}, {-978.970487195008, 987.5286801926}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.5349176018457527`*^9}]
}, {2}]],

Cell[TextData[{
 "In questo caso possiamo ben dire come al tendere allo zero dell'incremento \
non esista un valore definito verso il quale il rapporto incrementale appaia \
convergere: anzi manifesta \[EGrave] la sua divergenza in valore assoluto.\n\
Infine, per rendere l'esito del calcolo precedente ancora pi\[UGrave] \
esplicito forniamo una tabella dove assegnamo all'incremento ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 " valori molto piccoli: corrispondentemente, il rapporto incrementale mostra \
chiaramente una convergenza verso il valore ",
 Cell[BoxData[
  FormBox["0.5", TraditionalForm]]],
 "."
}], "Text",
 CellTags->"derivata_f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{"tabellaRappIncrementale", "[", 
      RowBox[{"f", ",", 
       RowBox[{"\[Pi]", "/", "3"}], ",", "10"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<incremento h\>\"", ",", "Bold", ",", 
         RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<rapp. incrementale\>\"", ",", "Bold", ",", 
         RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", "Right", "}"}]}], ",", 
   RowBox[{"ItemStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"FontSize", "\[Rule]", "8"}], "]"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"tabella"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"incremento h\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->8,
      FontWeight->Bold], 
     StyleBox["\<\"rapp. incrementale\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->8,
      FontWeight->Bold]},
    {"0.1`", "0.45590188541076104`"},
    {"0.01`", "0.4956615757736871`"},
    {"0.001`", "0.49956690400077`"},
    {"0.0001`", "0.49995669789693054`"},
    {"0.00001`", "0.499995669867026`"},
    {"1.`*^-6", "0.4999995669718871`"},
    {"1.`*^-7", "0.49999995699323563`"},
    {"1.`*^-8", "0.4999999969612645`"},
    {"1.`*^-9", "0.5000000413701854`"},
    {"1.`*^-10", "0.5000000413701855`"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Right}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{
        Directive[FontSize -> 8]}}, "Rows" -> {{
        Directive[FontSize -> 8]}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.5349176019081526`*^9},
 CellTags->"tabella"]
}, {2}]],

Cell[TextData[{
 "Riprendendo la ",
 ButtonBox["funzione g",
  BaseStyle->"Hyperlink",
  ButtonData:>"funzione_g"],
 " analizziamo pure per essa e per mezzo del calcolo l'andamento del rapporto \
incrementale in intorni, questa volta, del punto di ascissa ",
 Cell[BoxData[
  FormBox["0.5", TraditionalForm]]],
 "."
}], "Text",
 CellTags->"derivata_g"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{"tabellaRappIncrementale", "[", 
      RowBox[{"g", ",", "0.5", ",", "10"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<incremento h\>\"", ",", "Bold", ",", 
         RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<rapp. incrementale\>\"", ",", "Bold", ",", 
         RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", "Right", "}"}]}], ",", 
   RowBox[{"ItemStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"FontSize", "\[Rule]", "8"}], "]"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"tabella"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"incremento h\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->8,
      FontWeight->Bold], 
     StyleBox["\<\"rapp. incrementale\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->8,
      FontWeight->Bold]},
    {"0.1`", "0.8611053092608323`"},
    {"0.01`", "1.5616200194711105`"},
    {"0.001`", "1.654015044851298`"},
    {"0.0001`", "1.6635273038834164`"},
    {"0.00001`", "1.6644813137678403`"},
    {"1.`*^-6", "1.6645767426659575`"},
    {"1.`*^-7", "1.6645862854769433`"},
    {"1.`*^-8", "1.6645872458198596`"},
    {"1.`*^-9", "1.6645872458198594`"},
    {"1.`*^-10", "1.664587356842162`"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Right}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{
        Directive[FontSize -> 8]}}, "Rows" -> {{
        Directive[FontSize -> 8]}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.5349176019549522`*^9},
 CellTags->"tabella"]
}, {2}]],

Cell[TextData[{
 "Anche in questo caso emerge la convergenza del rapporto verso il valore ",
 Cell[BoxData[
  FormBox["1.66459", TraditionalForm]]],
 ".\nConcludiamo ripercorrendo per una terza funzione ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " lo studio, sia grafico che numerico, del rapporto incrementale. Definita \
la funzione come"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"t", "[", "x_", "]"}], ":=", 
  RowBox[{
   SuperscriptBox["x", "2"], 
   RowBox[{"(", 
    RowBox[{"x", "-", "1"}], ")"}]}]}]], "Input",
 CellTags->"funzione_t"],

Cell["uno zoom attorno al suo punto di ascissa 1 mostra", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zoom", "[", 
  RowBox[{"t", ",", "1"}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`semiAmpiezza$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`semiAmpiezza$$], 1, 0.001, 0.001}}, Typeset`size$$ = {
    540., {174., 184.}}, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = False, $CellContext`semiAmpiezza$1463$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`semiAmpiezza$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`semiAmpiezza$$, $CellContext`semiAmpiezza$1463$$, 
         0]}, "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> Show[
        Plot[
         $CellContext`t[$CellContext`x], {$CellContext`x, 
          1 - $CellContext`semiAmpiezza$$, 1 + $CellContext`semiAmpiezza$$}, 
         AxesOrigin -> {1 - $CellContext`semiAmpiezza$$, 
           $CellContext`t[1]}, PlotStyle -> Red], 
        Graphics[{
          PointSize[0.025], Blue, 
          Point[{1, 
            $CellContext`t[1]}]}], PlotLabel -> Style[
          StringJoin["intervallo [", 
           ToString[
            PaddedForm[
             N[1 - $CellContext`semiAmpiezza$$], {5, 4}]], ",", 
           ToString[
            PaddedForm[
             N[1 + $CellContext`semiAmpiezza$$], {5, 4}]], "]"], FontFamily -> 
          "Helvetica", FontSize -> 11, Background -> Lighter[Yellow]]], 
      "Specifications" :> {{$CellContext`semiAmpiezza$$, 1, 0.001, 0.001}}, 
      "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{612., {242., 251.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`t[
         Pattern[$CellContext`x, 
          Blank[]]] := $CellContext`x^2 ($CellContext`x - 1)}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5349176020485525`*^9}]
}, Open  ]],

Cell["\<\
l'esistenza di un andamento approssimativamente lineare a piccola scala. \
Evidenziando il triangolo coinvolgente gli incrementi abbiamo\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"finestra", "[", 
    RowBox[{"t", ",", "1", ",", "h", ",", "margineX"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"h", ",", 
       RowBox[{"-", ".235"}], ",", "\"\<incremento h\>\""}], "}"}], ",", 
     RowBox[{"-", "1"}], ",", "1", ",", "0.0001"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"margineX", ",", "0.5", ",", "\"\<ingrandimento\>\""}], "}"}], 
     ",", "0", ",", "1.2", ",", "0.0001"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`h$$ = -0.235, $CellContext`margineX$$ = 0.5,
     Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`h$$], -0.235, "incremento h"}, -1, 1, 0.0001}, {{
       Hold[$CellContext`margineX$$], 0.5, "ingrandimento"}, 0, 1.2, 0.0001}},
     Typeset`size$$ = {420., {319., 329.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`h$1490$$ = 0, $CellContext`margineX$1491$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`h$$ = -0.235, $CellContext`margineX$$ = 
        0.5}, "ControllerVariables" :> {
        Hold[$CellContext`h$$, $CellContext`h$1490$$, 0], 
        Hold[$CellContext`margineX$$, $CellContext`margineX$1491$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> $CellContext`finestra[$CellContext`t, 
        1, $CellContext`h$$, $CellContext`margineX$$], 
      "Specifications" :> {{{$CellContext`h$$, -0.235, "incremento h"}, -1, 1,
          0.0001}, {{$CellContext`margineX$$, 0.5, "ingrandimento"}, 0, 1.2, 
         0.0001}}, "Options" :> {}, 
      "DefaultOptions" :> {ControlPlacement -> Top, SaveDefinitions -> True}],
     ImageSizeCache->{492., {408., 417.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>({$CellContext`finestra[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          Blank[]], 
         Pattern[$CellContext`margine, 
          Blank[]]] := 
       Module[{$CellContext`cornice, $CellContext`minY, $CellContext`maxY}, \
$CellContext`cornice = 
          Abs[$CellContext`f[$CellContext`x0 - $CellContext`margine] - \
$CellContext`f[$CellContext`x0 + $CellContext`margine]]/10; $CellContext`minY = 
          If[$CellContext`f[$CellContext`x0 - $CellContext`margine] <= \
$CellContext`f[$CellContext`x0 + $CellContext`margine], \
$CellContext`f[$CellContext`x0 - $CellContext`margine] - \
$CellContext`cornice, $CellContext`f[$CellContext`x0 + $CellContext`margine] - \
$CellContext`cornice]; $CellContext`maxY = 
          If[$CellContext`f[$CellContext`x0 - $CellContext`margine] <= \
$CellContext`f[$CellContext`x0 + $CellContext`margine], \
$CellContext`f[$CellContext`x0 + $CellContext`margine] + \
$CellContext`cornice, $CellContext`f[$CellContext`x0 - $CellContext`margine] + \
$CellContext`cornice]; $CellContext`graficiSecantiTriangolo[$CellContext`f, \
$CellContext`x0, $CellContext`h, {{$CellContext`x0 - $CellContext`margine, \
$CellContext`x0 + $CellContext`margine}, {$CellContext`minY, \
$CellContext`maxY}}]], $CellContext`f[
         Pattern[$CellContext`x, 
          Blank[]]] := 
       Sin[$CellContext`x], $CellContext`graficiSecantiTriangolo[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          Blank[]], 
         Pattern[$CellContext`estremi, 
          Blank[List]]] := Module[{$CellContext`x}, 
         If[$CellContext`h != 0, 
          Show[
           Graphics[{
             RGBColor[1, 0.9, 0], 
             Polygon[{{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}, {$CellContext`x0, 
                $CellContext`f[$CellContext`x0 + $CellContext`h]}, \
{$CellContext`x0 + $CellContext`h, 
                $CellContext`f[$CellContext`x0 + $CellContext`h]}}]}], 
           Plot[{
             $CellContext`f[$CellContext`x], 
             $CellContext`secante[$CellContext`f, $CellContext`x, \
$CellContext`x0, $CellContext`h]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], {Red, 
              Point[{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}]}, 
             Point[{$CellContext`x0 + $CellContext`h, 
               $CellContext`f[$CellContext`x0 + $CellContext`h]}]}], 
           PlotRange -> $CellContext`estremi, Axes -> True, PlotLabel -> Style[
             StringJoin["coeff. angolare =", 
              ToString[
               PaddedForm[
                $CellContext`rappIncrementale[$CellContext`f, \
$CellContext`x0, $CellContext`h], {7, 6}]]], FontFamily -> "Helvetica", 
             FontSize -> 11, Background -> Lighter[Yellow]]], 
          Show[
           Plot[{
             $CellContext`f[$CellContext`x], 
             Derivative[
               1][$CellContext`f][$CellContext`x0] ($CellContext`x - \
$CellContext`x0) + $CellContext`f[$CellContext`x0]}, {$CellContext`x, 
             Part[$CellContext`estremi, 1, 1], 
             Part[$CellContext`estremi, 1, 2]}, PlotStyle -> {Red, Blue}], 
           Graphics[{
             PointSize[Large], {Red, 
              Point[{$CellContext`x0, 
                $CellContext`f[$CellContext`x0]}]}}], 
           PlotRange -> $CellContext`estremi, Axes -> True, PlotLabel -> Style[
             StringJoin["coeff. angolare =", 
              ToString[
               PaddedForm[
                N[
                 Derivative[1][$CellContext`f][$CellContext`x0]], {7, 6}]]], 
             FontFamily -> "Helvetica", FontSize -> 11, Background -> 
             Lighter[Yellow]]]]], $CellContext`secante[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := $CellContext`rappIncrementale[$CellContext`f, \
$CellContext`x0, $CellContext`h] ($CellContext`x - $CellContext`x0) + \
$CellContext`f[$CellContext`x0], $CellContext`rappIncrementale[
         Pattern[$CellContext`f, 
          Blank[]], 
         Pattern[$CellContext`x0, 
          Blank[]], 
         Pattern[$CellContext`h, 
          
          Blank[]]] := ($CellContext`f[$CellContext`h + $CellContext`x0] - \
$CellContext`f[$CellContext`x0])/$CellContext`h, 
       Attributes[Derivative] = {NHoldAll, ReadProtected}, $CellContext`t[
         Pattern[$CellContext`x, 
          Blank[]]] := $CellContext`x^2 ($CellContext`x - 1)}; 
     Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{3.5349176022045527`*^9}]
}, Open  ]],

Cell["\<\
e la costanza del rapporto appare pi\[UGrave] evidente se si passa a scale pi\
\[UGrave] piccole.\
\>", "Text"],

Cell[TextData[{
 "Il calcolo numerico dei rapporti a partire da un incremento unitario per \
giungere al valore di ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "2"}]], TraditionalForm]]],
 " fornisce la tabella seguente"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Row", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Grid", "[", 
      RowBox[{
       RowBox[{"Prepend", "[", 
        RowBox[{"#", ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Style", "[", 
            RowBox[{"\"\<incremento h\>\"", ",", "Bold", ",", 
             RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], 
           ",", 
           RowBox[{"Style", "[", 
            RowBox[{"\"\<rapp. incrementale\>\"", ",", "Bold", ",", 
             RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
             RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], 
            "]"}]}], "}"}]}], "]"}], ",", 
       RowBox[{"Alignment", "\[Rule]", 
        RowBox[{"{", "Right", "}"}]}], ",", 
       RowBox[{"Frame", "\[Rule]", "All"}], ",", 
       RowBox[{"ItemStyle", "\[Rule]", 
        RowBox[{"Directive", "[", 
         RowBox[{"FontSize", "\[Rule]", "8"}], "]"}]}]}], "]"}], "&"}], "/@", 
    RowBox[{"Partition", "[", 
     RowBox[{
      RowBox[{"tavolaCoeffAngolare", "[", 
       RowBox[{"t", ",", "1", ",", "1", ",", "100"}], "]"}], ",", "50"}], 
     "]"}]}], ",", "\"\<   \>\""}], "]"}]], "Input"],

Cell[BoxData[
 TemplateBox[{TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {"1.`", "4.`"}, {
       RowBox[{"-", "1.`"}], "0.`"}, {"0.5`", "2.25`"}, {
       RowBox[{"-", "0.5`"}], "0.25`"}, {
      "0.3333333333333333`", "1.7777777777777777`"}, {
       RowBox[{"-", "0.3333333333333333`"}], "0.4444444444444444`"}, {
      "0.25`", "1.5625`"}, {
       RowBox[{"-", "0.25`"}], "0.5625`"}, {"0.2`", "1.44`"}, {
       RowBox[{"-", "0.2`"}], "0.64`"}, {
      "0.16666666666666666`", "1.3611111111111112`"}, {
       RowBox[{"-", "0.16666666666666666`"}], "0.6944444444444444`"}, {
      "0.14285714285714285`", "1.3061224489795917`"}, {
       RowBox[{"-", "0.14285714285714285`"}], "0.7346938775510204`"}, {
      "0.125`", "1.265625`"}, {
       RowBox[{"-", "0.125`"}], "0.765625`"}, {
      "0.1111111111111111`", "1.2345679012345678`"}, {
       RowBox[{"-", "0.1111111111111111`"}], "0.7901234567901234`"}, {
      "0.1`", "1.21`"}, {
       RowBox[{"-", "0.1`"}], "0.81`"}, {
      "0.09090909090909091`", "1.1900826446280992`"}, {
       RowBox[{"-", "0.09090909090909091`"}], "0.8264462809917356`"}, {
      "0.08333333333333333`", "1.1736111111111112`"}, {
       RowBox[{"-", "0.08333333333333333`"}], "0.8402777777777778`"}, {
      "0.07692307692307693`", "1.1597633136094674`"}, {
       RowBox[{"-", "0.07692307692307693`"}], "0.8520710059171598`"}, {
      "0.07142857142857142`", "1.1479591836734695`"}, {
       RowBox[{"-", "0.07142857142857142`"}], "0.8622448979591837`"}, {
      "0.06666666666666667`", "1.1377777777777778`"}, {
       RowBox[{"-", "0.06666666666666667`"}], "0.8711111111111111`"}, {
      "0.0625`", "1.12890625`"}, {
       RowBox[{"-", "0.0625`"}], "0.87890625`"}, {
      "0.058823529411764705`", "1.1211072664359862`"}, {
       RowBox[{"-", "0.058823529411764705`"}], "0.8858131487889274`"}, {
      "0.05555555555555555`", "1.1141975308641976`"}, {
       RowBox[{"-", "0.05555555555555555`"}], "0.8919753086419753`"}, {
      "0.05263157894736842`", "1.10803324099723`"}, {
       RowBox[{"-", "0.05263157894736842`"}], "0.8975069252077562`"}, {
      "0.05`", "1.1025`"}, {
       RowBox[{"-", "0.05`"}], "0.9025`"}, {
      "0.047619047619047616`", "1.0975056689342404`"}, {
       RowBox[{"-", "0.047619047619047616`"}], "0.9070294784580499`"}, {
      "0.045454545454545456`", "1.0929752066115703`"}, {
       RowBox[{"-", "0.045454545454545456`"}], "0.9111570247933884`"}, {
      "0.043478260869565216`", "1.0888468809073724`"}, {
       RowBox[{"-", "0.043478260869565216`"}], "0.9149338374291115`"}, {
      "0.041666666666666664`", "1.0850694444444444`"}, {
       RowBox[{"-", "0.041666666666666664`"}], "0.9184027777777778`"}, {
      "0.04`", "1.0816`"}, {
       RowBox[{"-", "0.04`"}], "0.9216`"}}, AutoDelete -> False, 
     GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"],TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {
      "0.038461538461538464`", "1.0784023668639053`"}, {
       RowBox[{"-", "0.038461538461538464`"}], "0.9245562130177515`"}, {
      "0.037037037037037035`", "1.075445816186557`"}, {
       RowBox[{"-", "0.037037037037037035`"}], "0.9272976680384087`"}, {
      "0.03571428571428571`", "1.072704081632653`"}, {
       RowBox[{"-", "0.03571428571428571`"}], "0.9298469387755102`"}, {
      "0.034482758620689655`", "1.070154577883472`"}, {
       RowBox[{"-", "0.034482758620689655`"}], "0.9322235434007135`"}, {
      "0.03333333333333333`", "1.0677777777777777`"}, {
       RowBox[{"-", "0.03333333333333333`"}], "0.9344444444444444`"}, {
      "0.03225806451612903`", "1.065556711758585`"}, {
       RowBox[{"-", "0.03225806451612903`"}], "0.9365244536940687`"}, {
      "0.03125`", "1.0634765625`"}, {
       RowBox[{"-", "0.03125`"}], "0.9384765625`"}, {
      "0.030303030303030304`", "1.061524334251607`"}, {
       RowBox[{"-", "0.030303030303030304`"}], "0.9403122130394858`"}, {
      "0.029411764705882353`", "1.0596885813148789`"}, {
       RowBox[{"-", "0.029411764705882353`"}], "0.9420415224913494`"}, {
      "0.02857142857142857`", "1.0579591836734694`"}, {
       RowBox[{"-", "0.02857142857142857`"}], "0.9436734693877551`"}, {
      "0.027777777777777776`", "1.0563271604938271`"}, {
       RowBox[{"-", "0.027777777777777776`"}], "0.9452160493827161`"}, {
      "0.02702702702702703`", "1.0547845142439738`"}, {
       RowBox[{"-", "0.02702702702702703`"}], "0.9466764061358656`"}, {
      "0.02631578947368421`", "1.0533240997229918`"}, {
       RowBox[{"-", "0.02631578947368421`"}], "0.9480609418282548`"}, {
      "0.02564102564102564`", "1.051939513477975`"}, {
       RowBox[{"-", "0.02564102564102564`"}], "0.9493754109138725`"}, {
      "0.025`", "1.050625`"}, {
       RowBox[{"-", "0.025`"}], "0.950625`"}, {
      "0.024390243902439025`", "1.0493753718024985`"}, {
       RowBox[{"-", "0.024390243902439025`"}], "0.9518143961927424`"}, {
      "0.023809523809523808`", "1.0481859410430838`"}, {
       RowBox[{"-", "0.023809523809523808`"}], "0.9529478458049887`"}, {
      "0.023255813953488372`", "1.0470524607896161`"}, {
       RowBox[{"-", "0.023255813953488372`"}], "0.9540292049756626`"}, {
      "0.022727272727272728`", "1.0459710743801653`"}, {
       RowBox[{"-", "0.022727272727272728`"}], "0.9550619834710744`"}, {
      "0.022222222222222223`", "1.0449382716049382`"}, {
       RowBox[{"-", "0.022222222222222223`"}], "0.9560493827160493`"}, {
      "0.021739130434782608`", "1.0439508506616257`"}, {
       RowBox[{"-", "0.021739130434782608`"}], "0.9569943289224953`"}, {
      "0.02127659574468085`", "1.0430058850158443`"}, {
       RowBox[{"-", "0.02127659574468085`"}], "0.9578995020371208`"}, {
      "0.020833333333333332`", "1.0421006944444444`"}, {
       RowBox[{"-", "0.020833333333333332`"}], "0.9587673611111112`"}, {
      "0.02040816326530612`", "1.0412328196584757`"}, {
       RowBox[{"-", "0.02040816326530612`"}], "0.9596001665972511`"}, {
      "0.02`", "1.0404`"}, {
       RowBox[{"-", "0.02`"}], "0.9604`"}}, AutoDelete -> False, 
     GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"],TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {
      "0.0196078431372549`", "1.039600153787005`"}, {
       RowBox[{"-", "0.0196078431372549`"}], "0.9611687812379854`"}, {
      "0.019230769230769232`", "1.0388313609467457`"}, {
       RowBox[{"-", "0.019230769230769232`"}], "0.9619082840236687`"}, {
      "0.018867924528301886`", "1.0380918476326095`"}, {
       RowBox[{"-", "0.018867924528301886`"}], "0.9626201495194019`"}, {
      "0.018518518518518517`", "1.0373799725651578`"}, {
       RowBox[{"-", "0.018518518518518517`"}], "0.9633058984910837`"}, {
      "0.01818181818181818`", "1.036694214876033`"}, {
       RowBox[{"-", "0.01818181818181818`"}], "0.9639669421487603`"}, {
      "0.017857142857142856`", "1.0360331632653061`"}, {
       RowBox[{"-", "0.017857142857142856`"}], "0.9646045918367347`"}, {
      "0.017543859649122806`", "1.0353955063096338`"}, {
       RowBox[{"-", "0.017543859649122806`"}], "0.9652200677131425`"}, {
      "0.017241379310344827`", "1.0347800237812128`"}, {
       RowBox[{"-", "0.017241379310344827`"}], "0.9658145065398336`"}, {
      "0.01694915254237288`", "1.0341855788566503`"}, {
       RowBox[{"-", "0.01694915254237288`"}], "0.9663889686871588`"}, {
      "0.016666666666666666`", "1.033611111111111`"}, {
       RowBox[{"-", "0.016666666666666666`"}], "0.9669444444444445`"}, {
      "0.01639344262295082`", "1.0330556302069336`"}, {
       RowBox[{"-", "0.01639344262295082`"}], "0.9674818597151303`"}, {
      "0.016129032258064516`", "1.0325182101977106`"}, {
       RowBox[{"-", "0.016129032258064516`"}], "0.9680020811654526`"}, {
      "0.015873015873015872`", "1.0319979843789369`"}, {
       RowBox[{"-", "0.015873015873015872`"}], "0.9685059208868733`"}, {
      "0.015625`", "1.031494140625`"}, {
       RowBox[{"-", "0.015625`"}], "0.968994140625`"}, {
      "0.015384615384615385`", "1.0310059171597634`"}, {
       RowBox[{"-", "0.015384615384615385`"}], "0.9694674556213018`"}, {
      "0.015151515151515152`", "1.030532598714417`"}, {
       RowBox[{"-", "0.015151515151515152`"}], "0.9699265381083563`"}, {
      "0.014925373134328358`", "1.0300735130318557`"}, {
       RowBox[{"-", "0.014925373134328358`"}], "0.9703720204945422`"}, {
      "0.014705882352941176`", "1.029628027681661`"}, {
       RowBox[{"-", "0.014705882352941176`"}], "0.9708044982698962`"}, {
      "0.014492753623188406`", "1.0291955471539593`"}, {
       RowBox[{"-", "0.014492753623188406`"}], "0.9712245326612057`"}, {
      "0.014285714285714285`", "1.0287755102040816`"}, {
       RowBox[{"-", "0.014285714285714285`"}], "0.9716326530612245`"}, {
      "0.014084507042253521`", "1.0283673874231303`"}, {
       RowBox[{"-", "0.014084507042253521`"}], "0.9720293592541163`"}, {
      "0.013888888888888888`", "1.0279706790123457`"}, {
       RowBox[{"-", "0.013888888888888888`"}], "0.9724151234567902`"}, {
      "0.0136986301369863`", "1.0275849127416026`"}, {
       RowBox[{"-", "0.0136986301369863`"}], "0.9727903921936574`"}, {
      "0.013513513513513514`", "1.027209642074507`"}, {
       RowBox[{"-", "0.013513513513513514`"}], "0.9731555880204529`"}, {
      "0.013333333333333334`", "1.0268444444444444`"}, {
       RowBox[{"-", "0.013333333333333334`"}], "0.9735111111111111`"}}, 
     AutoDelete -> False, GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"],TagBox[
    GridBox[{{
       StyleBox[
       "\"incremento h\"", StripOnInput -> False, FontFamily -> "Helvetica", 
        FontSize -> 8, FontWeight -> Bold], 
       StyleBox[
       "\"rapp. incrementale\"", StripOnInput -> False, FontFamily -> 
        "Helvetica", FontSize -> 8, FontWeight -> Bold]}, {
      "0.013157894736842105`", "1.02648891966759`"}, {
       RowBox[{"-", "0.013157894736842105`"}], "0.9738573407202216`"}, {
      "0.012987012987012988`", "1.0261426884803508`"}, {
       RowBox[{"-", "0.012987012987012988`"}], "0.9741946365322989`"}, {
      "0.01282051282051282`", "1.0258053911900065`"}, {
       RowBox[{"-", "0.01282051282051282`"}], "0.9745233399079553`"}, {
      "0.012658227848101266`", "1.025476686428457`"}, {
       RowBox[{"-", "0.012658227848101266`"}], "0.9748437750360519`"}, {
      "0.0125`", "1.02515625`"}, {
       RowBox[{"-", "0.0125`"}], "0.97515625`"}, {
      "0.012345679012345678`", "1.0248437738149672`"}, {
       RowBox[{"-", "0.012345679012345678`"}], "0.9754610577655846`"}, {
      "0.012195121951219513`", "1.0245389649018442`"}, {
       RowBox[{"-", "0.012195121951219513`"}], "0.9757584770969661`"}, {
      "0.012048192771084338`", "1.0242415444912178`"}, {
       RowBox[{"-", "0.012048192771084338`"}], "0.9760487734068806`"}, {
      "0.011904761904761904`", "1.023951247165533`"}, {
       RowBox[{"-", "0.011904761904761904`"}], "0.9763321995464853`"}, {
      "0.011764705882352941`", "1.0236678200692042`"}, {
       RowBox[{"-", "0.011764705882352941`"}], "0.9766089965397924`"}, {
      "0.011627906976744186`", "1.0233910221741482`"}, {
       RowBox[{"-", "0.011627906976744186`"}], "0.9768793942671714`"}, {
      "0.011494252873563218`", "1.0231206235962478`"}, {
       RowBox[{"-", "0.011494252873563218`"}], "0.977143612101995`"}, {
      "0.011363636363636364`", "1.0228564049586777`"}, {
       RowBox[{"-", "0.011363636363636364`"}], "0.9774018595041323`"}, {
      "0.011235955056179775`", "1.022598156798384`"}, {
       RowBox[{"-", "0.011235955056179775`"}], "0.977654336573665`"}, {
      "0.011111111111111112`", "1.0223456790123457`"}, {
       RowBox[{"-", "0.011111111111111112`"}], "0.9779012345679012`"}, {
      "0.01098901098901099`", "1.0220987803405386`"}, {
       RowBox[{"-", "0.01098901098901099`"}], "0.9781427363844947`"}, {
      "0.010869565217391304`", "1.0218572778827977`"}, {
       RowBox[{"-", "0.010869565217391304`"}], "0.9783790170132325`"}, {
      "0.010752688172043012`", "1.0216209966470111`"}, {
       RowBox[{"-", "0.010752688172043012`"}], "0.9786102439588392`"}, {
      "0.010638297872340425`", "1.0213897691263014`"}, {
       RowBox[{"-", "0.010638297872340425`"}], "0.9788365776369398`"}, {
      "0.010526315789473684`", "1.0211634349030472`"}, {
       RowBox[{"-", "0.010526315789473684`"}], "0.9790581717451523`"}, {
      "0.010416666666666666`", "1.0209418402777777`"}, {
       RowBox[{"-", "0.010416666666666666`"}], "0.9792751736111112`"}, {
      "0.010309278350515464`", "1.0207248379211393`"}, {
       RowBox[{"-", "0.010309278350515464`"}], "0.9794877245190775`"}, {
      "0.01020408163265306`", "1.020512286547272`"}, {
       RowBox[{"-", "0.01020408163265306`"}], "0.9796959600166597`"}, {
      "0.010101010101010102`", "1.0203040506070808`"}, {
       RowBox[{"-", "0.010101010101010102`"}], "0.9799000102030405`"}, {
      "0.01`", "1.0201`"}, {
       RowBox[{"-", "0.01`"}], "0.9801`"}}, AutoDelete -> False, 
     GridBoxAlignment -> {"Columns" -> {{Right}}}, 
     GridBoxFrame -> {"Columns" -> {{True}}, "Rows" -> {{True}}}, 
     GridBoxItemSize -> {"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxItemStyle -> {"Columns" -> {{
          Directive[FontSize -> 8]}}, "Rows" -> {{
          Directive[FontSize -> 8]}}}], "Grid"]},
  "Row",
  DisplayFunction->(RowBox[{#, "   ", #2, "   ", #3, "   ", #4}]& ),
  InterpretationFunction->(RowBox[{"Row", "[", 
     RowBox[{
       RowBox[{"{", 
         RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", "\"   \""}], 
     "]"}]& )]], "Output",
 CellChangeTimes->{3.5349176023605523`*^9}]
}, {2}]],

Cell["\<\
ben sintetizzata dalla rappresentazione grafica seguente: questa conferma \
visivamente la convergenza del rapporto verso l'unit\[AGrave].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"tavolaCoeffAngolare", "[", 
    RowBox[{"t", ",", "1", ",", "1", ",", "100"}], "]"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{"\"\<incremento\>\"", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<rapp. incrementale\>\"", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     "}"}]}]}], "]"}]], "Input"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxV1ntcjdkaB/AmlZRonC4qdHG/TRM1Bx3zqJg0mkpSISkxQkjHJZeGnWp3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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox[
     StyleBox[
     "\"incremento\"", FontFamily -> "Helvetica", StripOnInput -> False], 
     TraditionalForm], 
    FormBox[
     StyleBox[
     "\"rapp. incrementale\"", FontFamily -> "Helvetica", StripOnInput -> 
      False], TraditionalForm]},
  AxesOrigin->{0, 0.74},
  PlotRange->{{-0.11230158730158729`, 0.1130952380952381}, {0.74, 
   1.2270738851095995`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{3.534917602454152*^9}]
}, {2}]],

Cell["Diminuendo sensibilmente l'incremento, si ha infine", "Text",
 CellTags->"derivata_t"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{"tabellaRappIncrementale", "[", 
      RowBox[{"t", ",", "1", ",", "10"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Style", "[", 
        RowBox[{"\"\<incremento h\>\"", ",", "Bold", ",", 
         RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}], ",", 
       RowBox[{"Style", "[", 
        RowBox[{"\"\<rapp. incrementale\>\"", ",", "Bold", ",", 
         RowBox[{"FontSize", "\[Rule]", "8"}], ",", 
         RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
      "}"}]}], "]"}], ",", 
   RowBox[{"Alignment", "\[Rule]", 
    RowBox[{"{", "Right", "}"}]}], ",", 
   RowBox[{"ItemStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"FontSize", "\[Rule]", "8"}], "]"}]}], ",", 
   RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"tabella"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     StyleBox["\<\"incremento h\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->8,
      FontWeight->Bold], 
     StyleBox["\<\"rapp. incrementale\"\>",
      StripOnInput->False,
      FontFamily->"Helvetica",
      FontSize->8,
      FontWeight->Bold]},
    {"0.1`", "1.2100000000000013`"},
    {"0.01`", "1.020100000000001`"},
    {"0.001`", "1.0020009999998893`"},
    {"0.0001`", "1.0002000099998898`"},
    {"0.00001`", "1.0000200001065513`"},
    {"1.`*^-6", "1.000001999918733`"},
    {"1.`*^-7", "1.0000002005838775`"},
    {"1.`*^-8", "1.0000000139225287`"},
    {"1.`*^-9", "1.0000000847403712`"},
    {"1.`*^-10", "1.000000082940371`"}
   },
   AutoDelete->False,
   GridBoxAlignment->{"Columns" -> {{Right}}},
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
   GridBoxItemStyle->{"Columns" -> {{
        Directive[FontSize -> 8]}}, "Rows" -> {{
        Directive[FontSize -> 8]}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.5349176025009527`*^9},
 CellTags->"tabella"]
}, {2}]],

Cell[TextData[{
 "risultato che ci permette di affermare come il rapporto incrementale, \
calcolato in intorni del punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], "=", "1"}], TraditionalForm]]],
 ", tenda al valore 1 al tendere allo zero dell'incremento."
}], "Text",
 CellChangeTimes->{{3.5348338531421523`*^9, 3.5348338565741525`*^9}}],

Cell["\<\
In definitiva possiamo riassumere l'esito della nostra analisi nelle \
osservazioni seguenti (gi\[AGrave] parzialmente esposte in precedenza) e \
relative alle propriet\[AGrave] caratterizzanti solo determinati punti delle \
funzioni studiate:\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["dal punto di vista geometrico:",
  FontSlant->"Italic"],
 " al tendere del punto ",
 Cell[BoxData[
  FormBox["P", TraditionalForm]]],
 " a ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["P", "0"], TraditionalForm]]],
 ", le rette secanti approssimano sempre meglio l\[CloseCurlyQuote]andamento \
della funzione ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " confondendosi con il suo grafico approssimativamente lineare. Queste rette \
si avvicinano ad una retta limite (la tangente) che, passante per ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 ", approssima nel modo migliore l\[CloseCurlyQuote]andamento di ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 ":"
}], "Item"],

Cell[TextData[{
 StyleBox["dal punto di vista numerico:",
  FontSlant->"Italic"],
 " al tendere allo 0 dell\[CloseCurlyQuote]incremento ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 ", la variabilit\[AGrave] del rapporto incrementale diminuisce e questo \
mostra di convergere ad un ben preciso limite. "
}], "Item"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Definizione di derivata in un punto", "Section"],

Cell[TextData[{
 "Nelle precedenti sezioni abbiamo fornito la ",
 ButtonBox["definizione di rapporto incrementale",
  BaseStyle->"Hyperlink",
  ButtonData:>"rappIncrementale"],
 " di una funzione in un suo punto e studiato il suo andamento sia tramite la \
grafica che numericamente. Tutto ci\[OGrave] giustifica, almeno a livello \
intuitivo, la definizione seguente:"
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Definizione",
  FontSlant->"Italic"],
 ". Si definisce derivata di una funzione ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " in un suo punto ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 StyleBox[" il limite, se esiste finito, del rapporto incrementale, al \
tendere allo zero dell\[CloseCurlyQuote]incremento ",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox["h", TraditionalForm]],
  FontWeight->"Bold"],
 "."
}], "Subsubsection"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["x", "0"], ")"}]}], "=", 
    RowBox[{
     UnderscriptBox["lim", 
      RowBox[{"h", "\[Rule]", "0"}]], 
     StyleBox[
      FractionBox[
       RowBox[{
        RowBox[{"f", "(", 
         RowBox[{
          SubscriptBox["x", "0"], "+", "h"}], ")"}], "-", 
        RowBox[{"f", "(", 
         SubscriptBox["x", "0"], ")"}]}], "h"],
      FontSize->14]}]}], TraditionalForm]]],
 StyleBox["   ",
  FontFamily->"Arial"],
 "   con     ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"f", "'"}], 
     RowBox[{"(", 
      SubscriptBox["x", "0"], ")"}]}], "\[Element]", " ", 
    "\[DoubleStruckCapitalR]"}], TraditionalForm]]]
}], "Text",
 CellChangeTimes->{{3.563901961123541*^9, 3.563901966021941*^9}}],

Cell[TextData[{
 "Poich\[EAcute] poi, a livello geometrico, la retta tangente nel punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["P", "0"], "[", 
    RowBox[{
     SubscriptBox["x", 
      RowBox[{"0", ","}]], 
     RowBox[{"f", "(", 
      SubscriptBox["x", "0"], ")"}]}], "]"}], TraditionalForm]]],
 " del grafico della funzione ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " viene definita come il limite, se esiste, della retta secante al tendere \
del punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", "[", 
    RowBox[{
     RowBox[{
      SubscriptBox["x", "0"], "+", "h"}], ",", 
     RowBox[{"f", "(", 
      RowBox[{
       SubscriptBox["x", "0"], "+", "h"}], ")"}]}], "]"}], TraditionalForm]]],
 " a ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["P", "0"], TraditionalForm]]],
 " ossia al tendere allo zero di ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]],
 ", possiamo identificare la derivata in ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " come il coefficiente angolare della retta tangente. L'equazione di questa \
retta \[EGrave], nell'ipotesi di esistenza del limite dato sopra,"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"y", "-", 
    RowBox[{"f", "(", 
     SubscriptBox["x", "0"], ")"}]}], "=", 
   RowBox[{
    RowBox[{"f", "'"}], 
    RowBox[{"(", 
     SubscriptBox["x", "0"], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "-", 
      SubscriptBox["x", "0"]}], ")"}]}]}], TraditionalForm]], "DisplayFormula"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Esempi di calcolo formale di derivate", "Section"],

Cell[TextData[{
 "Procediamo in questa sezione al calcolo formale della derivata delle tre \
funzioni che abbiamo studiato precedentemente.\nPer la funzione ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]]],
 " nel punto ",
 Cell[BoxData[
  FormBox[
   FractionBox["\[Pi]", "3"], TraditionalForm]]],
 " il rapporto incrementale risulta"
}], "Text"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{
      FractionBox["\[Pi]", "3"], "+", "h"}], "]"}], "-", 
    RowBox[{"Sin", "[", 
     FractionBox["\[Pi]", "3"], "]"}]}], "h"], ";"}]], "Input"],

Cell[TextData[{
 "e se si usano le formule di prostaferesi per il seno si pu\[OGrave] \
fattorizzare a numeratore un termine del tipo ",
 Cell[BoxData[
  FormBox[
   RowBox[{"sin", "(", 
    FractionBox["h", "2"], ")"}], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"2", 
    RowBox[{"Cos", "[", 
     RowBox[{
      FractionBox["\[Pi]", "3"], "+", 
      FractionBox["h", "2"]}], "]"}], 
    RowBox[{"Sin", "[", 
     FractionBox["h", "2"], "]"}]}], "h"], ";"}]], "Input"],

Cell["\<\
Quest'ultima si pu\[OGrave] riscrivere come\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{
     RowBox[{"Sin", "[", 
      FractionBox["h", "2"], "]"}], " "}], 
    FractionBox["h", "2"]], 
   RowBox[{"Cos", "[", 
    RowBox[{
     FractionBox["\[Pi]", "3"], "+", 
     FractionBox["h", "2"]}], "]"}]}], ";"}]], "Input"],

Cell["\<\
per cui tenendo conto del primo limite fondamentale e della \
continuit\[AGrave] del coseno, il limite di tale espressione fornisce\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      RowBox[{"Sin", "[", 
       FractionBox["h", "2"], "]"}], " "}], 
     FractionBox["h", "2"]], 
    RowBox[{"Cos", "[", 
     RowBox[{
      FractionBox["\[Pi]", "3"], "+", 
      FractionBox["h", "2"]}], "]"}]}], ",", 
   RowBox[{"h", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox["1", "2"]], "Output",
 CellChangeTimes->{3.5349176027973523`*^9}]
}, Open  ]],

Cell[TextData[{
 "in accordo con ",
 Cell[BoxData[
  FormBox[
   ButtonBox[
    RowBox[{"quanto", " ", "ottenuto"}],
    BaseStyle->"Hyperlink",
    ButtonData:>"derivata_f"], TraditionalForm]]],
 " numericamente.\nPer la ",
 ButtonBox["funzione t",
  BaseStyle->"Hyperlink",
  ButtonData:>"funzione_t"],
 " calcoliamo, inizialmente nel punto generico di ascissa ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 ", il rapporto incrementale"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rappIncrementale", "[", 
  RowBox[{"t", ",", "x0", ",", "h"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "x0"}], ")"}]}], " ", 
    SuperscriptBox["x0", "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "h", "+", "x0"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"h", "+", "x0"}], ")"}], "2"]}]}], "h"]], "Output",
 CellChangeTimes->{3.5349176028597527`*^9}]
}, Open  ]],

Cell["\<\
Eseguendo i quadrati e raccogliendo i fattori comuni si ottiene per il \
numeratore\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Factor", "[", 
  RowBox[{"Expand", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "x0"}], ")"}]}], " ", 
     SuperscriptBox["x0", "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "h", "+", "x0"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"h", "+", "x0"}], ")"}], "2"]}]}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"h", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "h"}], "+", 
    SuperscriptBox["h", "2"], "-", 
    RowBox[{"2", " ", "x0"}], "+", 
    RowBox[{"3", " ", "h", " ", "x0"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["x0", "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.5349176029065523`*^9}]
}, Open  ]],

Cell["per cui semplificando discende", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  FractionBox[
   RowBox[{"(", 
    RowBox[{"h", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "h"}], "+", 
       SuperscriptBox["h", "2"], "-", 
       RowBox[{"2", " ", "x0"}], "+", 
       RowBox[{"3", " ", "h", " ", "x0"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["x0", "2"]}]}], ")"}]}], ")"}], "h"], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  SuperscriptBox["h", "2"], "+", 
  RowBox[{"x0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     RowBox[{"3", " ", "x0"}]}], ")"}]}], "+", 
  RowBox[{"h", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     RowBox[{"3", " ", "x0"}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{3.534917602968952*^9}]
}, Open  ]],

Cell[TextData[{
 "Volendo la derivata nel punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], "=", "1"}], TraditionalForm]]],
 ", si sostituisce questo valore ad ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["x", "0"], TraditionalForm]]],
 " giungendo a"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["h", "2"], "+", 
   RowBox[{"x0", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", 
      RowBox[{"3", " ", "x0"}]}], ")"}]}], "+", 
   RowBox[{"h", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"3", " ", "x0"}]}], ")"}]}]}], "/.", 
  RowBox[{"{", 
   RowBox[{"x0", "\[Rule]", "1"}], "}"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"1", "+", 
  RowBox[{"2", " ", "h"}], "+", 
  SuperscriptBox["h", "2"]}]], "Output",
 CellChangeTimes->{3.5349176030157523`*^9}]
}, Open  ]],

Cell[TextData[{
 "ed eseguendo il limite di tale argomento per ",
 Cell[BoxData[
  FormBox[
   RowBox[{"h", "\[Rule]", "0"}], TraditionalForm]]],
 " appare immediato ottenere"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"1", "+", 
    RowBox[{"2", " ", "h"}], "+", 
    SuperscriptBox["h", "2"]}], ",", 
   RowBox[{"h", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{3.5349176030625525`*^9}]
}, Open  ]],

Cell[TextData[{
 "che \[EGrave] il valore pure ",
 Cell[BoxData[
  FormBox[
   ButtonBox["aspettato",
    BaseStyle->"Hyperlink",
    ButtonData:>"derivata_t"], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "Passiamo infine al calcolo del limite del rapporto incrementale per la ",
 ButtonBox["funzione g",
  BaseStyle->"Hyperlink",
  ButtonData:>"funzione_g"],
 " nel punto ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "0"], "=", 
    FractionBox["1", "2"]}], TraditionalForm]]],
 ". Il rapporto incrementale nel punto di ascissa ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "2"], TraditionalForm]]],
 " risulta"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rappIncrementale", "[", 
  RowBox[{"g", ",", 
   FractionBox["1", "2"], ",", "h"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{
     FractionBox["1", "2"], "+", "h"}], "]"}], "-", 
   RowBox[{"Sin", "[", "2", "]"}]}], "h"]], "Output",
 CellChangeTimes->{3.5349176031249523`*^9}]
}, Open  ]],

Cell["che, tramite le formule di prostaferesi, si riscrive come", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"1", "+", "h"}], 
      RowBox[{
       FractionBox["1", "2"], "+", "h"}]], "]"}], " ", 
    RowBox[{"Sin", "[", 
     FractionBox["h", 
      RowBox[{
       FractionBox["1", "2"], "+", "h"}]], "]"}]}], "h"]}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"Cos", "[", 
     FractionBox[
      RowBox[{"1", "+", "h"}], 
      RowBox[{
       FractionBox["1", "2"], "+", "h"}]], "]"}], " ", 
    RowBox[{"Sin", "[", 
     FractionBox["h", 
      RowBox[{
       FractionBox["1", "2"], "+", "h"}]], "]"}]}], "h"]}]], "Output",
 CellChangeTimes->{3.5349176031717525`*^9}]
}, Open  ]],

Cell[TextData[{
 "Volendo trattare separatamente i termini ",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1", "+", "h"}], 
     RowBox[{
      FractionBox["1", "2"], "+", "h"}]], "]"}]}]]],
 " e ",
 Cell[BoxData[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", "  ", 
     RowBox[{"Sin", "[", 
      FractionBox["h", 
       RowBox[{
        FractionBox["1", "2"], "+", "h"}]], "]"}]}], "h"]}]]],
 ", introduciamo per il solo secondo fattore, la nuova variabile ",
 Cell[BoxData[
  FormBox[
   RowBox[{"z", "=", 
    FractionBox["h", 
     RowBox[{
      FractionBox["1", "2"], "+", "h"}]]}], TraditionalForm]]],
 " da cui ",
 Cell[BoxData[
  FormBox["h", TraditionalForm]]]
}], "Text",
 CellTags->"2fattori"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"z", "==", 
      FractionBox["h", 
       RowBox[{
        FractionBox["1", "2"], "+", "h"}]]}], ",", "h"}], "]"}], ",", "1"}], 
  "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"h", "\[Rule]", 
   RowBox[{"-", 
    FractionBox["z", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", "z"}], ")"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{3.5349176032341523`*^9}]
}, Open  ]],

Cell[TextData[{
 "Il termine ",
 Cell[BoxData[
  RowBox[{"-", 
   FractionBox[
    RowBox[{"2", "  ", 
     RowBox[{"Sin", "[", 
      FractionBox["h", 
       RowBox[{
        FractionBox["1", "2"], "+", "h"}]], "]"}]}], "h"]}]]],
 "assume di conseguenza la forma pi\[UGrave] semplice"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", "  ", 
      RowBox[{"Sin", "[", 
       FractionBox["h", 
        RowBox[{
         FractionBox["1", "2"], "+", "h"}]], "]"}]}], "h"]}], "/.", 
   RowBox[{"{", 
    RowBox[{"h", "\[Rule]", 
     RowBox[{"-", 
      FractionBox["z", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "z"}], ")"}]}]]}]}], "}"}]}], 
  "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
   RowBox[{"Sin", "[", "z", "]"}]}], "z"]], "Output",
 CellChangeTimes->{3.5349176032809525`*^9}]
}, Open  ]],

Cell["e il suo limite \[EGrave]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   FractionBox[
    RowBox[{"4", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "z"}], ")"}], " ", 
     RowBox[{"Sin", "[", "z", "]"}]}], "z"], ",", 
   RowBox[{"z", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", "4"}]], "Output",
 CellChangeTimes->{3.534917603327752*^9}]
}, Open  ]],

Cell[TextData[{
 "L'",
 ButtonBox["altro fattore",
  BaseStyle->"Hyperlink",
  ButtonData:>"2fattori"],
 " del rapporto incrementale conduce al limite"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"Cos", "[", 
    FractionBox[
     RowBox[{"1", "+", "h"}], 
     RowBox[{
      FractionBox["1", "2"], "+", "h"}]], "]"}], ",", 
   RowBox[{"h", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"Cos", "[", "2", "]"}]], "Output",
 CellChangeTimes->{3.5349176034213524`*^9}]
}, Open  ]],

Cell["per cui in definitiva si ha", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Limit", "[", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{"Cos", "[", 
       FractionBox[
        RowBox[{"1", "+", "h"}], 
        RowBox[{
         FractionBox["1", "2"], "+", "h"}]], "]"}], " ", 
      RowBox[{"Sin", "[", 
       FractionBox["h", 
        RowBox[{
         FractionBox["1", "2"], "+", "h"}]], "]"}]}], "h"]}], ",", 
   RowBox[{"h", "\[Rule]", "0"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "4"}], " ", 
  RowBox[{"Cos", "[", "2", "]"}]}]], "Output",
 CellChangeTimes->{3.5349176035773525`*^9}]
}, Open  ]],

Cell["Numericamente tale limite equivale a", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"Cos", "[", "2", "]"}]}], "]"}]], "Input"],

Cell[BoxData["1.6645873461885696`"], "Output",
 CellChangeTimes->{3.5349176036553526`*^9}]
}, Open  ]],

Cell[TextData[{
 "che coincide con quanto ",
 ButtonBox["gi\[AGrave] trovato",
  BaseStyle->"Hyperlink",
  ButtonData:>"derivata_g"],
 " precedentemente per altra via."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
PrintingStyleEnvironment->"OutputPDF",
WindowToolbars->{},
WindowSize->{1241, 829},
WindowMargins->{{-1390, Automatic}, {Automatic, -13}},
PrintingCopies->1,
PrintingPageRange->{32000, 32000},
PrintingOptions->{"Magnification"->1.,
"PaperOrientation"->"Portrait",
"PaperSize"->{595.1999999999999, 841.98},
"PrintCellBrackets"->False,
"PrintMultipleHorizontalPages"->False,
"PrintRegistrationMarks"->False,
"PrintingMargins"->{{0., 0.}, {42.499842980100006`, 42.499842980100006`}}},
CellLabelAutoDelete->True,
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"9.0 for Microsoft Windows (32-bit) (November 20, 2012)",
StyleDefinitions->FrontEnd`FileName[{"Creative"}, "NaturalColor.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "funzione_g"->{
  Cell[38061, 923, 307, 10, 96, "Input",
   CellTags->"funzione_g"]},
 "rappIncrementale"->{
  Cell[48459, 1205, 386, 13, 59, "DisplayFormula",
   CellTags->"rappIncrementale"]},
 "figura1"->{
  Cell[50544, 1295, 3950, 113, 372, "Input",
   CellTags->"figura1"],
  Cell[54497, 1410, 8340, 144, 308, "Output",
   CellTags->"figura1"]},
 "derivata_f"->{
  Cell[130315, 2933, 658, 14, 159, "Text",
   CellTags->"derivata_f"]},
 "tabella"->{
  Cell[130998, 2951, 1013, 25, 210, "Input",
   CellTags->"tabella"],
  Cell[132014, 2978, 1145, 33, 340, "Output",
   CellTags->"tabella"],
  Cell[133548, 3029, 983, 24, 210, "Input",
   CellTags->"tabella"],
  Cell[134534, 3055, 1143, 33, 340, "Output",
   CellTags->"tabella"],
  Cell[167966, 3760, 981, 24, 210, "Input",
   CellTags->"tabella"],
  Cell[168950, 3786, 1142, 33, 340, "Output",
   CellTags->"tabella"]},
 "derivata_g"->{
  Cell[133171, 3014, 352, 11, 74, "Text",
   CellTags->"derivata_g"]},
 "funzione_t"->{
  Cell[136055, 3102, 196, 7, 62, "Input",
   CellTags->"funzione_t"]},
 "derivata_t"->{
  Cell[167849, 3755, 92, 1, 45, "Text",
   CellTags->"derivata_t"]},
 "2fattori"->{
  Cell[183635, 4351, 752, 29, 205, "Text",
   CellTags->"2fattori"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"funzione_g", 189110, 4574},
 {"rappIncrementale", 189203, 4577},
 {"figura1", 189303, 4580},
 {"derivata_f", 189462, 4585},
 {"tabella", 189548, 4588},
 {"derivata_g", 189987, 4601},
 {"funzione_t", 190075, 4604},
 {"derivata_t", 190163, 4607},
 {"2fattori", 190247, 4610}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 43, 0, 98, "Title"],
Cell[CellGroupData[{
Cell[635, 26, 37, 0, 39, "Subsubsection"],
Cell[675, 28, 888, 16, 216, "Text"],
Cell[1566, 46, 356, 12, 34, "author"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1959, 63, 28, 0, 54, "Subsection"],
Cell[1990, 65, 20582, 518, 9193, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[22609, 588, 65, 0, 66, "Section"],
Cell[22677, 590, 76, 0, 45, "Text"],
Cell[22756, 592, 129, 4, 60, "Input"],
Cell[22888, 598, 232, 8, 45, "Text"],
Cell[CellGroupData[{
Cell[23145, 610, 243, 7, 60, "Input"],
Cell[23391, 619, 9388, 160, 361, "Output"]
}, Open  ]],
Cell[32794, 782, 1231, 38, 176, "Text"],
Cell[CellGroupData[{
Cell[34050, 824, 108, 3, 60, "Input"],
Cell[34161, 829, 2718, 56, 524, "Output"]
}, Open  ]],
Cell[36894, 888, 1164, 33, 215, "Text"],
Cell[38061, 923, 307, 10, 96, "Input",
 CellTags->"funzione_g"],
Cell[38371, 935, 71, 0, 45, "Text"],
Cell[CellGroupData[{
Cell[38467, 939, 80, 2, 60, "Input"],
Cell[38550, 943, 2574, 54, 518, "Output"]
}, Open  ]],
Cell[41139, 1000, 455, 11, 102, "Text"],
Cell[CellGroupData[{
Cell[41619, 1015, 82, 2, 60, "Input"],
Cell[41704, 1019, 2600, 55, 518, "Output"]
}, Open  ]],
Cell[44319, 1077, 507, 8, 159, "Text"],
Cell[CellGroupData[{
Cell[44851, 1089, 224, 4, 71, "Item"],
Cell[45078, 1095, 155, 3, 71, "Item"]
}, Open  ]],
Cell[45248, 1101, 228, 4, 74, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45513, 1110, 68, 0, 113, "Section"],
Cell[45584, 1112, 215, 4, 74, "Text"],
Cell[45802, 1118, 648, 20, 96, "Item"],
Cell[46453, 1140, 259, 9, 59, "DisplayFormula"],
Cell[46715, 1151, 1741, 52, 220, "Text"],
Cell[48459, 1205, 386, 13, 59, "DisplayFormula",
 CellTags->"rappIncrementale"],
Cell[48848, 1220, 47, 0, 45, "Text"],
Cell[CellGroupData[{
Cell[48920, 1224, 423, 16, 46, "Item"],
Cell[49346, 1242, 468, 18, 46, "Item"]
}, Open  ]],
Cell[49829, 1263, 154, 5, 45, "Text"],
Cell[49986, 1270, 533, 21, 74, "Text"],
Cell[CellGroupData[{
Cell[50544, 1295, 3950, 113, 372, "Input",
 CellTags->"figura1"],
Cell[54497, 1410, 8340, 144, 308, "Output",
 CellTags->"figura1"]
}, {2}]],
Cell[62849, 1557, 422, 13, 82, "Text"],
Cell[CellGroupData[{
Cell[63296, 1574, 565, 17, 90, "Input"],
Cell[63864, 1593, 4156, 95, 496, "Output"]
}, Open  ]],
Cell[68035, 1691, 980, 24, 232, "Text"],
Cell[CellGroupData[{
Cell[69040, 1719, 574, 17, 90, "Input"],
Cell[69617, 1738, 5181, 115, 444, "Output"]
}, Open  ]],
Cell[74813, 1856, 200, 4, 74, "Text"],
Cell[CellGroupData[{
Cell[75038, 1864, 596, 16, 90, "Input"],
Cell[75637, 1882, 6906, 146, 526, "Output"]
}, Open  ]],
Cell[82558, 2031, 118, 3, 45, "Text"],
Cell[CellGroupData[{
Cell[82701, 2038, 782, 23, 122, "Item"],
Cell[83486, 2063, 95, 2, 46, "Item"]
}, Open  ]],
Cell[83596, 2068, 239, 4, 74, "Text"],
Cell[83838, 2074, 724, 19, 139, "Text"],
Cell[84565, 2095, 416, 10, 102, "Text"],
Cell[CellGroupData[{
Cell[85006, 2109, 1278, 32, 177, "Input"],
Cell[86287, 2143, 15515, 261, 1420, "Output"]
}, Open  ]],
Cell[101817, 2407, 338, 9, 74, "Text"],
Cell[CellGroupData[{
Cell[102180, 2420, 593, 15, 169, "Input"],
Cell[102776, 2437, 3689, 71, 360, "Output"]
}, {2}]],
Cell[106477, 2511, 679, 18, 133, "Text"],
Cell[CellGroupData[{
Cell[107181, 2533, 589, 15, 178, "Input"],
Cell[107773, 2550, 22530, 380, 350, "Output"]
}, {2}]],
Cell[130315, 2933, 658, 14, 159, "Text",
 CellTags->"derivata_f"],
Cell[CellGroupData[{
Cell[130998, 2951, 1013, 25, 210, "Input",
 CellTags->"tabella"],
Cell[132014, 2978, 1145, 33, 340, "Output",
 CellTags->"tabella"]
}, {2}]],
Cell[133171, 3014, 352, 11, 74, "Text",
 CellTags->"derivata_g"],
Cell[CellGroupData[{
Cell[133548, 3029, 983, 24, 210, "Input",
 CellTags->"tabella"],
Cell[134534, 3055, 1143, 33, 340, "Output",
 CellTags->"tabella"]
}, {2}]],
Cell[135689, 3091, 363, 9, 102, "Text"],
Cell[136055, 3102, 196, 7, 62, "Input",
 CellTags->"funzione_t"],
Cell[136254, 3111, 65, 0, 45, "Text"],
Cell[CellGroupData[{
Cell[136344, 3115, 80, 2, 60, "Input"],
Cell[136427, 3119, 2525, 53, 532, "Output"]
}, Open  ]],
Cell[138967, 3175, 160, 3, 74, "Text"],
Cell[CellGroupData[{
Cell[139152, 3182, 561, 15, 90, "Input"],
Cell[139716, 3199, 6986, 147, 864, "Output"]
}, Open  ]],
Cell[146717, 3349, 121, 3, 45, "Text"],
Cell[146841, 3354, 258, 8, 76, "Text"],
Cell[CellGroupData[{
Cell[147124, 3366, 1244, 31, 250, "Input"],
Cell[148371, 3399, 15125, 258, 1420, "Output"]
}, {2}]],
Cell[163508, 3660, 162, 3, 74, "Text"],
Cell[CellGroupData[{
Cell[163695, 3667, 563, 14, 169, "Input"],
Cell[164261, 3683, 3576, 69, 360, "Output"]
}, {2}]],
Cell[167849, 3755, 92, 1, 45, "Text",
 CellTags->"derivata_t"],
Cell[CellGroupData[{
Cell[167966, 3760, 981, 24, 210, "Input",
 CellTags->"tabella"],
Cell[168950, 3786, 1142, 33, 340, "Output",
 CellTags->"tabella"]
}, {2}]],
Cell[170104, 3822, 364, 9, 74, "Text"],
Cell[170471, 3833, 267, 5, 74, "Text"],
Cell[CellGroupData[{
Cell[170763, 3842, 745, 23, 96, "Item"],
Cell[171511, 3867, 324, 8, 71, "Item"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[171884, 3881, 54, 0, 113, "Section"],
Cell[171941, 3883, 381, 8, 102, "Text"],
Cell[CellGroupData[{
Cell[172347, 3895, 502, 17, 62, "Subsubsection"],
Cell[172852, 3914, 852, 32, 57, "Text"],
Cell[173707, 3948, 1174, 38, 135, "Text"],
Cell[174884, 3988, 342, 12, 36, "DisplayFormula"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[175275, 4006, 56, 0, 113, "Section"],
Cell[175334, 4008, 350, 10, 110, "Text"],
Cell[175687, 4020, 236, 8, 98, "Input"],
Cell[175926, 4030, 257, 8, 56, "Text"],
Cell[176186, 4040, 257, 9, 99, "Input"],
Cell[176446, 4051, 67, 2, 45, "Text"],
Cell[176516, 4055, 293, 11, 114, "Input"],
Cell[176812, 4068, 155, 3, 74, "Text"],
Cell[CellGroupData[{
Cell[176992, 4075, 370, 13, 114, "Input"],
Cell[177365, 4090, 92, 2, 80, "Output"]
}, Open  ]],
Cell[177472, 4095, 480, 17, 74, "Text"],
Cell[CellGroupData[{
Cell[177977, 4116, 103, 2, 60, "Input"],
Cell[178083, 4120, 451, 16, 123, "Output"]
}, Open  ]],
Cell[178549, 4139, 107, 3, 63, "Text"],
Cell[CellGroupData[{
Cell[178681, 4146, 465, 16, 94, "Input"],
Cell[179149, 4164, 332, 10, 94, "Output"]
}, Open  ]],
Cell[179496, 4177, 46, 0, 63, "Text"],
Cell[CellGroupData[{
Cell[179567, 4181, 393, 12, 136, "Input"],
Cell[179963, 4195, 367, 13, 90, "Output"]
}, Open  ]],
Cell[180345, 4211, 288, 11, 63, "Text"],
Cell[CellGroupData[{
Cell[180658, 4226, 413, 15, 90, "Input"],
Cell[181074, 4243, 151, 4, 90, "Output"]
}, Open  ]],
Cell[181240, 4250, 187, 6, 63, "Text"],
Cell[CellGroupData[{
Cell[181452, 4260, 196, 6, 94, "Input"],
Cell[181651, 4268, 72, 1, 85, "Output"]
}, Open  ]],
Cell[181738, 4272, 197, 8, 63, "Text"],
Cell[181938, 4282, 457, 16, 141, "Text"],
Cell[CellGroupData[{
Cell[182420, 4302, 124, 3, 127, "Input"],
Cell[182547, 4307, 224, 7, 133, "Output"]
}, Open  ]],
Cell[182786, 4317, 73, 0, 63, "Text"],
Cell[CellGroupData[{
Cell[182884, 4321, 344, 12, 163, "Input"],
Cell[183231, 4335, 389, 13, 153, "Output"]
}, Open  ]],
Cell[183635, 4351, 752, 29, 205, "Text",
 CellTags->"2fattori"],
Cell[CellGroupData[{
Cell[184412, 4384, 251, 9, 148, "Input"],
Cell[184666, 4395, 270, 9, 115, "Output"]
}, Open  ]],
Cell[184951, 4407, 298, 11, 115, "Text"],
Cell[CellGroupData[{
Cell[185274, 4422, 488, 18, 168, "Input"],
Cell[185765, 4442, 226, 7, 117, "Output"]
}, Open  ]],
Cell[186006, 4452, 41, 0, 63, "Text"],
Cell[CellGroupData[{
Cell[186072, 4456, 277, 9, 127, "Input"],
Cell[186352, 4467, 87, 2, 85, "Output"]
}, Open  ]],
Cell[186454, 4472, 163, 6, 63, "Text"],
Cell[CellGroupData[{
Cell[186642, 4482, 242, 8, 150, "Input"],
Cell[186887, 4492, 101, 2, 85, "Output"]
}, Open  ]],
Cell[187003, 4497, 43, 0, 63, "Text"],
Cell[CellGroupData[{
Cell[187071, 4501, 452, 15, 163, "Input"],
Cell[187526, 4518, 142, 4, 85, "Output"]
}, Open  ]],
Cell[187683, 4525, 52, 0, 63, "Text"],
Cell[CellGroupData[{
Cell[187760, 4529, 127, 4, 87, "Input"],
Cell[187890, 4535, 90, 1, 85, "Output"]
}, Open  ]],
Cell[187995, 4539, 180, 6, 63, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
